@@ -53,6 +53,12 @@ PLANCKIDEFSource::~PLANCKIDEFSource( )
 bool PLANCKIDEFSource::isValidFilename( const QString& filename )
 {
   bool ok = false;
+  unsigned minLength = 21;
+
+  if( filename.right( 3 ).lower( ) == ".gz" ) 
+  {
+    minLength += 3;
+  }
 
   //
   // _yyyymmddhhmm_vv.fits
@@ -63,7 +69,7 @@ bool PLANCKIDEFSource::isValidFilename( const QString& filename )
   //  mm = two digits coding the start timeline minute
   //  vv = version number (to be used in case of regeneration of HK timelines, starting from 00)
   //
-  if( filename.length() > 21 )
+  if( filename.length() > minLength )
   {
     int year;
     int month;
@@ -72,7 +78,7 @@ bool PLANCKIDEFSource::isValidFilename( const QString& filename )
     int minute;
     int version;
 
-    QString tail = filename.right( 21 );
+    QString tail = filename.right( minLength );
 
     if( sscanf( tail.latin1(), "_%4d%2d%2d%2d%2d_%2d.fits", &year, &month, &day, &hour, &minute, &version ) == 6 )
     {
@@ -99,6 +105,12 @@ bool PLANCKIDEFSource::isValidFilename( const QString& filename )
 QString PLANCKIDEFSource::baseFilename( const QString& filename )
 {
   QString base;
+  unsigned minLength = 21;
+
+  if( filename.right( 3 ).lower( ) == ".gz" ) 
+  {
+    minLength += 3;
+  }
 
   //
   // _yyyymmddhhmm_vv.fits
@@ -109,9 +121,9 @@ QString PLANCKIDEFSource::baseFilename( const QString& filename )
   //  mm = two digits coding the start timeline minute
   //  vv = version number (to be used in case of regeneration of HK timelines, starting from 00)
   //
-  if( filename.length() > 21 )
+  if( filename.length() > minLength )
   {
-    base = filename.left( filename.length() - 21 );
+    base = filename.left( filename.length() - minLength );
   }
 
   return base;
@@ -121,6 +133,12 @@ QString PLANCKIDEFSource::baseFilename( const QString& filename )
 int PLANCKIDEFSource::versionNumber( const QString& filename )
 {
   int version = -1;
+  unsigned minLength = 21;
+
+  if( filename.right( 3 ).lower( ) == ".gz" ) 
+  {
+    minLength += 3;
+  }
 
   //
   // _yyyymmddhhmm_vv.fits
@@ -131,11 +149,11 @@ int PLANCKIDEFSource::versionNumber( const QString& filename )
   //  mm = two digits coding the start timeline minute
   //  vv = version number (to be used in case of regeneration of HK timelines, starting from 00)
   //
-  if( filename.length() > 21 )
+  if( filename.length() > minLength )
   {
     char time[13];
 
-    QString tail = filename.right( 21 );
+    QString tail = filename.right( minLength );
 
     if( sscanf( tail.latin1(), "_%12s_%2d.fits", time, &version ) != 2 )
     {
@@ -286,6 +304,10 @@ void PLANCKIDEFSource::addToFieldList( fitsfile *ffits, const QString& prefix, c
           else
           {
             str = QString( "%1/%2" ).arg( prefix ).arg( charName );
+            if( _fields.find( str ) != 0 )
+            {
+              str = QString( "%1/%2_%3" ).arg( prefix ).arg( charName ).arg( iHDUNumber-1 );
+            }
           }
 
           fld->basefile = baseName;
@@ -537,7 +559,7 @@ bool PLANCKIDEFSource::initFolderFile( const QString& filename, const QString& p
 
 bool PLANCKIDEFSource::initFolder( )
 {
-  QDir        folder( _filename, "*.fits", QDir::Name | QDir::IgnoreCase, QDir::Files | QDir::Readable );
+  QDir        folder( _filename, "*.fits *.fits.gz", QDir::Name | QDir::IgnoreCase, QDir::Files | QDir::Readable );
   QStringList files;
   QStringList filesBase;
   bool        bRetVal = true;
@@ -955,7 +977,7 @@ bool PLANCKIDEFSource::supportsHierarchy( ) const
 
 bool PLANCKIDEFSource::checkValidPlanckIDEFFolder( const QString& filename )
 {
-  QDir folder( filename, "*.fits", QDir::Name | QDir::IgnoreCase, QDir::Files | QDir::Readable );
+  QDir folder( filename, "*.fits *.fits.gz", QDir::Name | QDir::IgnoreCase, QDir::Files | QDir::Readable );
   QStringList files;
   QString pathname;
   bool ok = false;
