@@ -19,6 +19,7 @@
 #include "bind_point.h"
 #include "bind_vector.h"
 
+#include <ksthistogram.h>
 #include <kstcolorsequence.h>
 #include <kstdataobjectcollection.h>
 
@@ -62,6 +63,42 @@ KstBindCurve::~KstBindCurve() {
 
 KJS::Object KstBindCurve::construct(KJS::ExecState *exec, const KJS::List& args) {
   KstVectorPtr x, y, ex, ey, exm, eym;
+
+  if (args.size() == 1) {
+    KstDataObjectPtr obj;
+
+    obj = extractDataObject(exec, args[0]);
+    if (obj) {
+      KstHistogramPtr hs = kst_cast<KstHistogram>(obj);
+      if (hs) {
+        x = hs->vX();
+        y = hs->vY();
+        if (x && y) {
+          QColor color = KstColorSequence::next();
+          KstVCurvePtr d = new KstVCurve(QString::null, x, y, ex, ey, exm, eym, color);
+
+          d->setHasPoints(false);
+          d->setHasLines(false);
+          d->setHasBars(true);
+
+          KST::dataObjectList.lock().writeLock();
+          KST::dataObjectList.append(d.data());
+          KST::dataObjectList.lock().unlock();
+
+          return KJS::Object(new KstBindCurve(exec, d));
+        } else {
+          KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError, "The histogram must have an associated vector.");
+          exec->setException(eobj);
+          return KJS::Object();
+        }
+      } else {
+        KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
+        exec->setException(eobj);
+        return KJS::Object();
+      }
+    }
+  }
+
   if (args.size() > 0) {
     x = extractVector(exec, args[0]);
     if (!x) {
@@ -245,7 +282,7 @@ KJS::Value KstBindCurve::get(KJS::ExecState *exec, const KJS::Identifier& proper
       return (this->*curveProperties[i].get)(exec);
     }
   }
-  
+
   return KstBindDataObject::get(exec, propertyName);
 }
 
@@ -327,6 +364,12 @@ KJS::Value KstBindCurve::xErrorPoint(KJS::ExecState *exec, const KJS::List& args
     return KJS::Undefined();
   }
 
+  if (!d->xErrorVector()) {
+   KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError, "No +X error bar is defined.");
+    exec->setException(eobj);
+    return KJS::Undefined();
+  }
+
   unsigned i = 0;
   if (args[0].type() != KJS::NumberType || !args[0].toUInt32(i)) {
     KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
@@ -355,6 +398,12 @@ KJS::Value KstBindCurve::yErrorPoint(KJS::ExecState *exec, const KJS::List& args
     return KJS::Undefined();
   }
 
+  if (!d->yErrorVector()) {
+   KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError, "No +Y error bar is defined.");
+    exec->setException(eobj);
+    return KJS::Undefined();
+  }
+
   unsigned i = 0;
   if (args[0].type() != KJS::NumberType || !args[0].toUInt32(i)) {
     KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
@@ -383,6 +432,12 @@ KJS::Value KstBindCurve::xMinusErrorPoint(KJS::ExecState *exec, const KJS::List&
     return KJS::Undefined();
   }
 
+  if (!d->xMinusErrorVector()) {
+   KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError, "No -X error bar is defined.");
+    exec->setException(eobj);
+    return KJS::Undefined();
+  }
+
   unsigned i = 0;
   if (args[0].type() != KJS::NumberType || !args[0].toUInt32(i)) {
     KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
@@ -411,6 +466,12 @@ KJS::Value KstBindCurve::yMinusErrorPoint(KJS::ExecState *exec, const KJS::List&
     return KJS::Undefined();
   }
 
+  if (!d->yMinusErrorVector()) {
+   KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError, "No -Y error bar is defined.");
+    exec->setException(eobj);
+    return KJS::Undefined();
+  }
+
   unsigned i = 0;
   if (args[0].type() != KJS::NumberType || !args[0].toUInt32(i)) {
     KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
@@ -502,13 +563,22 @@ KJS::Value KstBindCurve::yVector(KJS::ExecState *exec) const {
 
 
 void KstBindCurve::setXErrorVector(KJS::ExecState *exec, const KJS::Value& value) {
-  KstVectorPtr vp = extractVector(exec, value);
+  KstVectorPtr vp = extractVector(exec, value, false);
   if (vp) {
     KstVCurvePtr d = makeCurve(_d);
     if (d) {
       KstWriteLocker wl(d);
       d->setXError(vp);
     }
+  } else if (value.toString(exec).qstring().stripWhiteSpace().isEmpty()) {
+    KstVCurvePtr d = makeCurve(_d);
+    if (d) {
+      KstWriteLocker wl(d);
+      d->setXError(vp);
+    }
+  } else {
+    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError, "Failed to extract vector.");
+    exec->setException(eobj);
   }
 }
 
@@ -527,13 +597,22 @@ KJS::Value KstBindCurve::xErrorVector(KJS::ExecState *exec) const {
 
 
 void KstBindCurve::setYErrorVector(KJS::ExecState *exec, const KJS::Value& value) {
-  KstVectorPtr vp = extractVector(exec, value);
+  KstVectorPtr vp = extractVector(exec, value, false);
   if (vp) {
     KstVCurvePtr d = makeCurve(_d);
     if (d) {
       KstWriteLocker wl(d);
       d->setYError(vp);
     }
+  } else if (value.toString(exec).qstring().stripWhiteSpace().isEmpty()) {
+    KstVCurvePtr d = makeCurve(_d);
+    if (d) {
+      KstWriteLocker wl(d);
+      d->setYError(vp);
+    }
+  } else {
+    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError, "Failed to extract vector.");
+    exec->setException(eobj);
   }
 }
 
@@ -552,13 +631,22 @@ KJS::Value KstBindCurve::yErrorVector(KJS::ExecState *exec) const {
 
 
 void KstBindCurve::setXMinusErrorVector(KJS::ExecState *exec, const KJS::Value& value) {
-  KstVCurvePtr d = makeCurve(_d);
-  if (d) {
-    KstVectorPtr vp = extractVector(exec, value);
-    if (vp) {
+  KstVectorPtr vp = extractVector(exec, value, false);
+  if (vp) {
+    KstVCurvePtr d = makeCurve(_d);
+    if (d) {
       KstWriteLocker wl(d);
       d->setXMinusError(vp);
     }
+  } else if (value.toString(exec).qstring().stripWhiteSpace().isEmpty()) {
+    KstVCurvePtr d = makeCurve(_d);
+    if (d) {
+      KstWriteLocker wl(d);
+      d->setXMinusError(vp);
+    }
+  } else {
+    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError, "Failed to extract vector.");
+    exec->setException(eobj);
   }
 }
 
@@ -577,13 +665,22 @@ KJS::Value KstBindCurve::xMinusErrorVector(KJS::ExecState *exec) const {
 
 
 void KstBindCurve::setYMinusErrorVector(KJS::ExecState *exec, const KJS::Value& value) {
-  KstVCurvePtr d = makeCurve(_d);
-  if (d) {
-    KstVectorPtr vp = extractVector(exec, value);
-    if (vp) {
+  KstVectorPtr vp = extractVector(exec, value, false);
+  if (vp) {
+    KstVCurvePtr d = makeCurve(_d);
+    if (d) {
       KstWriteLocker wl(d);
       d->setYMinusError(vp);
     }
+  } else if (value.toString(exec).qstring().stripWhiteSpace().isEmpty()) {
+    KstVCurvePtr d = makeCurve(_d);
+    if (d) {
+      KstWriteLocker wl(d);
+      d->setYMinusError(vp);
+    }
+  } else {
+    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError, "Failed to extract vector.");
+    exec->setException(eobj);
   }
 }
 
@@ -713,16 +810,17 @@ KJS::Value KstBindCurve::hasBars(KJS::ExecState *exec) const {
 
 
 void KstBindCurve::setLineWidth(KJS::ExecState *exec, const KJS::Value& value) {
-  unsigned i = 0;
-  if (value.type() != KJS::NumberType || !value.toUInt32(i)) {
+  unsigned width = 0;
+  if (value.type() != KJS::NumberType || !value.toUInt32(width)) {
     KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
     exec->setException(eobj);
     return;
   }
+
   KstVCurvePtr d = makeCurve(_d);
   if (d) {
     KstWriteLocker wl(d);
-    d->setLineWidth(i);
+    d->setLineWidth(width);
   }
 }
 
