@@ -17,6 +17,8 @@
 
 #include "bind_matrix.h"
 
+#include <kst.h>
+#include <kstdoc.h>
 #include <kstamatrix.h>
 #include <kstdatacollection.h>
 
@@ -50,7 +52,12 @@ KstBindMatrix::~KstBindMatrix() {
 
 
 KJS::Object KstBindMatrix::construct(KJS::ExecState *exec, const KJS::List& args) {
-  Q_UNUSED(args)
+  if (args.size() != 0) {
+    KJS::Object eobj = KJS::Error::create(exec, KJS::SyntaxError, "Requires no arguments.");
+    exec->setException(eobj);
+    return KJS::Object();
+  }
+
   return KJS::Object(new KstBindMatrix(exec));
 }
 
@@ -71,6 +78,9 @@ struct MatrixProperties {
 static MatrixBindings matrixBindings[] = {
   { "resize", &KstBindMatrix::resize },
   { "zero", &KstBindMatrix::zero },
+  { "value", &KstBindMatrix::value },
+  { "setValue", &KstBindMatrix::setValue },
+  { "update", &KstBindMatrix::update },
   { 0L, 0L }
 };
 
@@ -187,24 +197,45 @@ KJS::Value KstBindMatrix::editable(KJS::ExecState *exec) const {
 
 
 KJS::Value KstBindMatrix::min(KJS::ExecState *exec) const {
-  Q_UNUSED(exec)
   KstMatrixPtr m = makeMatrix(_d);
+  if (!m) {
+    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
+    exec->setException(eobj);
+    return KJS::Undefined();
+  }
+  if (m->dirty()) {
+    m->update();
+  }
   KstReadLocker rl(m);
   return KJS::Number(m->minValue());
 }
 
 
 KJS::Value KstBindMatrix::max(KJS::ExecState *exec) const {
-  Q_UNUSED(exec)
   KstMatrixPtr m = makeMatrix(_d);
+  if (!m) {
+    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
+    exec->setException(eobj);
+    return KJS::Undefined();
+  }
+  if (m->dirty()) {
+    m->update();
+  }
   KstReadLocker rl(m);
   return KJS::Number(m->maxValue());
 }
 
 
 KJS::Value KstBindMatrix::mean(KJS::ExecState *exec) const {
-  Q_UNUSED(exec)
   KstMatrixPtr m = makeMatrix(_d);
+  if (!m) {
+    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
+    exec->setException(eobj);
+    return KJS::Undefined();
+  }
+  if (m->dirty()) {
+    m->update();
+  }
   KstReadLocker rl(m);
   return KJS::Number(m->meanValue());
 }
@@ -264,6 +295,7 @@ KJS::Value KstBindMatrix::resize(KJS::ExecState *exec, const KJS::List& args) {
 
   m->writeLock();
   m->resize(rows, cols);
+  KstApp::inst()->document()->wasModified();
   m->unlock();
 
   return KJS::Undefined();
@@ -280,6 +312,114 @@ KJS::Value KstBindMatrix::zero(KJS::ExecState *exec, const KJS::List& args) {
   }
   KstWriteLocker wl(m);
   m->zero();
+  KstApp::inst()->document()->wasModified();
+  return KJS::Undefined();
+}
+
+
+KJS::Value KstBindMatrix::value(KJS::ExecState *exec, const KJS::List& args) {
+  if (args.size() != 2) {
+    KJS::Object eobj = KJS::Error::create(exec, KJS::SyntaxError, "Requires exactly two arguments.");
+    exec->setException(eobj);
+    return KJS::Undefined();
+  }
+
+  KstMatrixPtr m = makeMatrix(_d);
+  if (!m) {
+    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
+    exec->setException(eobj);
+    return KJS::Undefined();
+  }
+
+  unsigned x, y;
+  double value;
+  bool ok;
+
+  if (args[0].type() != KJS::NumberType || !args[0].toUInt32(x)) {
+    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
+    exec->setException(eobj);
+    return KJS::Undefined();
+  }
+
+  if (args[1].type() != KJS::NumberType || !args[1].toUInt32(y)) {
+    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
+    exec->setException(eobj);
+    return KJS::Undefined();
+  }
+
+  KstReadLocker wl(m);
+  value = m->valueRaw(x, y, &ok);
+  if (!ok) {
+    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
+    exec->setException(eobj);
+    return KJS::Undefined();
+  }
+
+  return KJS::Number(value);
+}
+
+
+KJS::Value KstBindMatrix::setValue(KJS::ExecState *exec, const KJS::List& args) {
+  if (args.size() != 3) {
+    KJS::Object eobj = KJS::Error::create(exec, KJS::SyntaxError, "Requires exactly three arguments.");
+    exec->setException(eobj);
+    return KJS::Undefined();
+  }
+
+  KstMatrixPtr m = makeMatrix(_d);
+  if (!m || !m->editable()) {
+    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
+    exec->setException(eobj);
+    return KJS::Undefined();
+  }
+
+  unsigned x, y;
+  double z;
+
+  if (args[0].type() != KJS::NumberType || !args[0].toUInt32(x)) {
+    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
+    exec->setException(eobj);
+    return KJS::Undefined();
+  }
+
+  if (args[1].type() != KJS::NumberType || !args[1].toUInt32(y)) {
+    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
+    exec->setException(eobj);
+    return KJS::Undefined();
+  }
+
+  if (args[2].type() != KJS::NumberType) {
+    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
+    exec->setException(eobj);
+    return KJS::Undefined();
+  } else {
+    z = args[2].toNumber(exec);
+  }
+
+  KstWriteLocker wl(m);
+  if (!m->setValueRaw(x, y, z)) {
+    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
+    exec->setException(eobj);
+    return KJS::Undefined();
+  } else {
+    m->setDirty();
+  }
+
+  return KJS::Boolean(true);
+}
+
+
+KJS::Value KstBindMatrix::update(KJS::ExecState *exec, const KJS::List& args) {
+  Q_UNUSED(args)
+  KstMatrixPtr m = makeMatrix(_d);
+  if (!m || !m->editable()) {
+    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
+    exec->setException(eobj);
+    return KJS::Undefined();
+  }
+  KstWriteLocker wl(m);
+  m->update();
+  KstApp::inst()->document()->wasModified();
   return KJS::Undefined();
 }
 
@@ -294,5 +434,3 @@ int KstBindMatrix::propertyCount() const {
 }
 
 #undef makeMatrix
-
-// vim: ts=2 sw=2 et
