@@ -73,6 +73,11 @@ static ViewObjectBindings viewObjectBindings[] = {
   { "resize", &KstBindViewObject::resize },
   { "move", &KstBindViewObject::move },
   { "convertTo", &KstBindViewObject::convertTo },
+  { "raiseToTop", &KstBindViewObject::raiseToTop },
+  { "lowerToBottom", &KstBindViewObject::lowerToBottom },
+  { "raise", &KstBindViewObject::raise },
+  { "lower", &KstBindViewObject::lower },
+  { "remove", &KstBindViewObject::remove },
   { 0L, 0L }
 };
 
@@ -449,8 +454,16 @@ KJS::Value KstBindViewObject::resize(KJS::ExecState *exec, const KJS::List& args
   if (d) {
     KstWriteLocker rl(d);
     d->resize(QSize(x, y));
+
+    KstViewObjectPtr vo = d->topLevelParent();
+    if (vo) {
+      KstTopLevelViewPtr tlv =  kst_cast<KstTopLevelView>(vo);
+      if (tlv) {
+        tlv->paint(KstPainter::P_PAINT);
+      }
+    }
   }
-  
+
   return KJS::Undefined();
 }
 
@@ -483,8 +496,16 @@ KJS::Value KstBindViewObject::move(KJS::ExecState *exec, const KJS::List& args)
   if (d) {
     KstWriteLocker rl(d);
     d->move(QPoint(x, y));
+
+    KstViewObjectPtr vo = d->topLevelParent();
+    if (vo) {
+      KstTopLevelViewPtr tlv =  kst_cast<KstTopLevelView>(vo);
+      if (tlv) {
+        tlv->paint(KstPainter::P_PAINT);
+      }
+    }
   }
-  
+
   return KJS::Undefined();
 }
 
@@ -506,7 +527,7 @@ KJS::Value KstBindViewObject::convertTo(KJS::ExecState *exec, const KJS::List& a
   if (type == "ViewObject") {
     return KJS::Object(new KstBindViewObject(exec, kst_cast<KstViewObject>(_d)));
   }
-  
+
   if (_factoryMap.contains(type)) {
     KstBindViewObject *o = (_factoryMap[type])(exec, kst_cast<KstViewObject>(_d));
     if (o) {
@@ -518,6 +539,146 @@ KJS::Value KstBindViewObject::convertTo(KJS::ExecState *exec, const KJS::List& a
 }
 
 
+KJS::Value KstBindViewObject::raiseToTop(KJS::ExecState *exec, const KJS::List& args) {
+  if (args.size() != 0) {
+    KJS::Object eobj = KJS::Error::create(exec, KJS::SyntaxError, "Requires no arguments.");
+    exec->setException(eobj);
+    return KJS::Null();
+  }
+
+  KstViewObjectPtr d = makeViewObject(_d);
+  if (d) {
+    KstReadLocker rl(d);
+
+    d->raiseToTop();
+    KstViewObjectPtr vo = d->topLevelParent();
+    if (vo) {
+      KstTopLevelViewPtr tlv =  kst_cast<KstTopLevelView>(vo);
+      if (tlv) {
+        tlv->paint(KstPainter::P_PAINT);
+      }
+    }
+  }
+
+  return KJS::Undefined();
+}
+
+
+KJS::Value KstBindViewObject::lowerToBottom(KJS::ExecState *exec, const KJS::List& args) {
+  if (args.size() != 0) {
+    KJS::Object eobj = KJS::Error::create(exec, KJS::SyntaxError, "Requires no arguments.");
+    exec->setException(eobj);
+    return KJS::Null();
+  }
+
+  KstViewObjectPtr d = makeViewObject(_d);
+  if (d) {
+    KstReadLocker rl(d);
+
+    d->lowerToBottom();
+    KstViewObjectPtr vo = d->topLevelParent();
+    if (vo) {
+      KstTopLevelViewPtr tlv =  kst_cast<KstTopLevelView>(vo);
+      if (tlv) {
+        tlv->paint(KstPainter::P_PAINT);
+      }
+    }
+  }
+
+  return KJS::Undefined();
+}
+
+
+KJS::Value KstBindViewObject::raise(KJS::ExecState *exec, const KJS::List& args) {
+  if (args.size() != 0) {
+    KJS::Object eobj = KJS::Error::create(exec, KJS::SyntaxError, "Requires no arguments.");
+    exec->setException(eobj);
+    return KJS::Null();
+  }
+
+  KstViewObjectPtr d = makeViewObject(_d);
+  if (d) {
+    KstReadLocker rl(d);
+
+    d->raise();
+    KstViewObjectPtr vo = d->topLevelParent();
+    if (vo) {
+      KstTopLevelViewPtr tlv =  kst_cast<KstTopLevelView>(vo);
+      if (tlv) {
+        tlv->paint(KstPainter::P_PAINT);
+      }
+    }
+  }
+
+  return KJS::Undefined();
+}
+
+
+KJS::Value KstBindViewObject::lower(KJS::ExecState *exec, const KJS::List& args) {
+  if (args.size() != 0) {
+    KJS::Object eobj = KJS::Error::create(exec, KJS::SyntaxError, "Requires no arguments.");
+    exec->setException(eobj);
+    return KJS::Null();
+  }
+
+  KstViewObjectPtr d = makeViewObject(_d);
+  if (d) {
+    KstReadLocker rl(d);
+
+    d->lower();
+    KstViewObjectPtr vo = d->topLevelParent();
+    if (vo) {
+      KstTopLevelViewPtr tlv =  kst_cast<KstTopLevelView>(vo);
+      if (tlv) {
+        tlv->paint(KstPainter::P_PAINT);
+      }
+    }
+  }
+
+  return KJS::Undefined();
+}
+
+
+KJS::Value KstBindViewObject::remove(KJS::ExecState *exec, const KJS::List& args) {
+  if (args.size() != 0) {
+    KJS::Object eobj = KJS::Error::create(exec, KJS::SyntaxError, "Requires no arguments.");
+    exec->setException(eobj);
+    return KJS::Null();
+  }
+
+  {
+    KstViewObjectPtr d = makeViewObject(_d);
+    KstTopLevelViewPtr tlvTest =  kst_cast<KstTopLevelView>(_d);
+
+    if (tlvTest) {
+      KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError, "Unable to delete the view.");
+      exec->setException(eobj);
+      return KJS::Null();
+    }
+
+    KstViewObjectPtr vo;
+
+    if (d) {
+      KstReadLocker rl(d);
+
+      vo = d->topLevelParent();
+      d->remove();
+    }
+
+    if (vo) {
+      KstTopLevelViewPtr tlv =  kst_cast<KstTopLevelView>(vo);
+      if (tlv) {
+        tlv->paint(KstPainter::P_PAINT);
+      }
+    }
+  }
+
+  delete this;
+
+  return KJS::Undefined();
+}
+
+
 KJS::Value KstBindViewObject::findChild(KJS::ExecState *exec, const KJS::List& args) {
   if (args.size() != 1) {
     KJS::Object eobj = KJS::Error::create(exec, KJS::SyntaxError, "Requires exactly one argument.");
@@ -540,7 +701,7 @@ KJS::Value KstBindViewObject::findChild(KJS::ExecState *exec, const KJS::List& a
       return KJS::Object(KstBindViewObject::bind(exec, vop));
     }
   }
-  
+
   return KJS::Null();
 }
 
@@ -570,7 +731,7 @@ KstBindViewObject *KstBindViewObject::bind(KJS::ExecState *exec, KstViewObjectPt
   if (!obj) {
     return 0L;
   }
-  
+
   if (_factoryMap.contains(obj->type())) {
     KstBindViewObject *o = (_factoryMap[obj->type()])(exec, obj);
     if (o) {
@@ -590,5 +751,3 @@ QMap<QString, KstBindViewObject*(*)(KJS::ExecState*, KstViewObjectPtr)> KstBindV
 
 #undef makeViewObject
 
-
-// vim: ts=2 sw=2 et
