@@ -57,7 +57,7 @@ void KstDataSource::cleanupForExit() {
 
 static QString obtainFile(const QString& source) {
   KURL url;
-  
+
   if (QFile::exists(source) && QFileInfo(source).isRelative()) {
     url.setPath(source);
   } else {
@@ -467,17 +467,13 @@ KstDataSource::KstDataSource(KConfig *cfg, const QString& filename, const QStrin
 
 
 KstDataSource::~KstDataSource() {
-//  kstdDebug() << "KstDataSource destructor: " << tag().tagString() << endl;
   KST::scalarList.lock().writeLock();
-//  kstdDebug() << "  removing numFrames scalar" << endl;
   KST::scalarList.remove(_numFramesScalar);
   KST::scalarList.lock().unlock();
 
-//  kstdDebug() << "  removing metadata strings" << endl;
   KST::stringList.lock().writeLock();
   KST::stringList.setUpdateDisplayTags(false);
   for (QDictIterator<KstString> it(_metaData); it.current(); ++it) {
-//    kstdDebug() << "    removing " << it.current()->tag().tagString() << endl;
     KST::stringList.remove(it.current());
   }
   KST::stringList.setUpdateDisplayTags(true);
@@ -556,8 +552,8 @@ int KstDataSource::readMatrix(KstMatrixData* data, const QString& matrix, int xS
   Q_UNUSED(skip)
   return -9999;
 }
- 
-  
+
+
 int KstDataSource::readMatrix(KstMatrixData* data, const QString& matrix, int xStart, int yStart, int xNumSteps, int yNumSteps) {
   Q_UNUSED(data)
   Q_UNUSED(matrix)
@@ -623,7 +619,7 @@ QStringList KstDataSource::fieldList() const {
 
 
 QStringList KstDataSource::matrixList() const { 
-  return _matrixList;  
+  return _matrixList;
 }
 
 
@@ -765,6 +761,21 @@ void KstDataSource::disableReuse() {
 }
 
 
+QString KstDataSource::configuration(QString setting) {
+  Q_UNUSED(setting)
+
+  return QString();
+}
+
+
+bool KstDataSource::setConfiguration(QString setting, const QString &value) {
+  Q_UNUSED(setting)
+  Q_UNUSED(value)
+
+  return false;
+}
+
+
 /////////////////////////////////////////////////////////////////////////////
 KstDataSourceConfigWidget::KstDataSourceConfigWidget()
 : QWidget(0L), _cfg(0L) {
@@ -797,7 +808,4 @@ KstDataSourcePtr KstDataSourceConfigWidget::instance() const {
   return _instance;
 }
 
-
-
 #include "kstdatasource.moc"
-// vim: ts=2 sw=2 et
