@@ -178,6 +178,7 @@ void KstRVector::change(KstDataSourcePtr in_file, const QString &in_field,
                         int reqStartingFrame, int reqNumberFrames,
                         int skip, bool doSkip, bool doAve) {
   Q_ASSERT(myLockStatus() == KstRWLock::WRITELOCKED);
+  Q_UNUSED(in_tag);
 
   _skip = skip;
   _doSkip = doSkip;
@@ -187,13 +188,12 @@ void KstRVector::change(KstDataSourcePtr in_file, const QString &in_field,
   }
 
   _dontUseSkipAccel = false;
-  _file = in_file;
+  if (in_file != _file) {
+    changeFile(in_file);
+  }
   _reqStartingFrame = reqStartingFrame;
   _reqNumberFrames = reqNumberFrames;
   _field = in_field;
-  if (in_tag != tag()) {
-    setTagName(in_tag);
-  }
 
   if (_file) {
     _file->writeLock();
@@ -206,7 +206,6 @@ void KstRVector::change(KstDataSourcePtr in_file, const QString &in_field,
   if (_reqNumberFrames <= 0 && _reqStartingFrame < 0) {
     _reqStartingFrame = 0;
   }
-
 }
 
 
@@ -326,7 +325,6 @@ int KstRVector::reqStartFrame() const {
 }
 
 
-/** Save vector information */
 void KstRVector::save(QTextStream &ts, const QString& indent, bool saveAbsolutePosition) {
   if (_saveData) {
     // This is ugly.  Really we need a way to change vector types at runtime.
@@ -361,7 +359,6 @@ void KstRVector::save(QTextStream &ts, const QString& indent, bool saveAbsoluteP
 }
 
 
-/** return the name of the file */
 QString KstRVector::filename() const {
   QString rc;
   if (_file) {
@@ -373,7 +370,6 @@ QString KstRVector::filename() const {
 }
 
 
-/** return the field */
 const QString& KstRVector::field() const {
   return _field;
 }
@@ -439,7 +435,6 @@ void KstRVector::checkIntegrity() {
 }
 
 
-/** Update an RVECTOR */
 KstObject::UpdateType KstRVector::update(int update_counter) {
   Q_ASSERT(myLockStatus() == KstRWLock::WRITELOCKED);
 
@@ -653,7 +648,7 @@ KstObject::UpdateType KstRVector::doUpdate(bool force) {
     }
   }
 
-  NumNew = _size - _numSamples;
+  _numNew = _size - _numSamples;
   _numberOfFrames = newNumberOfFrames;
   _startingFrame = newStartingFrame;
   _numSamples += nRead;
@@ -674,11 +669,11 @@ KstObject::UpdateType KstRVector::doUpdate(bool force) {
     }
   }
 
-  if (NumNew > _size) {
-    NumNew = _size;
+  if (_numNew > _size) {
+    _numNew = _size;
   }
-  if (NumShifted > _size) {
-    NumShifted = _size;
+  if (_numShifted > _size) {
+    _numShifted = _size;
   }
 
   return KstVector::internalUpdate(UPDATE);
@@ -750,8 +745,7 @@ KstDataSourcePtr KstRVector::dataSource() const {
 
 KstRVectorPtr KstRVector::makeDuplicate() const {
   QString newTag = tag().tag() + "'";
+
   return new KstRVector(_file, _field, KstObjectTag(newTag, tag().context()), _reqStartingFrame, _reqNumberFrames, _skip, _doSkip, _doAve);
 }
 
-
-// vim: ts=2 sw=2 et
