@@ -23,7 +23,7 @@ KstSVector::KstSVector(const QDomElement &e) : KstVector(e) {
   double in_x1 = 1.0;
   int in_n = 2;
 
-  /* parse the DOM tree */
+  // parse the DOM tree
   QDomNode n = e.firstChild();
   while (!n.isNull()) {
     QDomElement e = n.toElement();
@@ -45,8 +45,7 @@ KstSVector::KstSVector(const QDomElement &e) : KstVector(e) {
 }
 
 
-KstSVector::KstSVector(double x0, double x1, int n, KstObjectTag tag) :
-    KstVector(tag, n) {
+KstSVector::KstSVector(double x0, double x1, int n, KstObjectTag tag) : KstVector(tag, n) {
   _saveable = true;
   _saveData = false;
   changeRange( x0, x1, n );
