@@ -83,6 +83,7 @@
 #include "kstsettingsdlg_i.h"
 #include "kstuinames.h"
 #include "kstvectordefaults.h"
+#include "kstvectorsavedialog_i.h"
 #include "kstvectordialog_i.h"
 #include "kstviewmanager_i.h"
 #include "kstviewscalarsdialog_i.h"
@@ -90,6 +91,7 @@
 #include "kstviewvectorsdialog_i.h"
 #include "kstviewmatricesdialog_i.h"
 #include "kstviewfitsdialog_i.h"
+#include "kstviewwidget.h"
 #include "kstviewwindow.h"
 #include "plotmimesource.h"
 #include "plugincollection.h"
@@ -98,7 +100,6 @@
 #include "statuslabel.h"
 #include "sysinfo.h"
 #include "updatethread.h"
-#include "vectorsavedialog.h"
 #include "kstobjectdefaults.h"
 
 #define MODE_BUTTON_ID       5
@@ -161,7 +162,7 @@ KstApp::KstApp(QWidget *parent, const char *name)
   differentiateCurvesDialog = new KstCurveDifferentiateI(this);
   changeNptsDialog = new KstChangeNptsDialogI(this);
   graphFileDialog = new KstGraphFileDialogI(this);
-  vectorSaveDialog = new VectorSaveDialog(this);
+  vectorSaveDialog = new KstVectorSaveDialogI(this);
   _monochromeDialog = new KstMonochromeDialogI(this);
 #ifdef KST_QUICKSTART_DLG
   _quickStartDialog = new KstQuickStartDialogI(this, 0 , true);
@@ -794,7 +795,7 @@ void KstApp::initActions() {
   _gfxPictureAction->setExclusiveGroup("gfx");
   _gfxPictureAction->setToolTip(i18n("Insert picture"));
   _gfxPictureAction->setWhatsThis(i18n("Insert picture"));
-  
+
   _gfx2DPlotAction = new KRadioAction(i18n("&Plot"), "kst_newplot",
                                    KShortcut(CTRL+Key_2),
                                    this, SLOT(toggleMouseMode()),
@@ -811,6 +812,14 @@ void KstApp::initActions() {
   _gfxArrowAction->setToolTip(i18n("Draw arrow"));
   _gfxArrowAction->setWhatsThis(i18n("Draw arrow"));
 
+  _gfxLegendAction = new KRadioAction(i18n("&Legend"), "kst_gfx_legend",
+                                   KShortcut(CTRL+Key_3),
+                                   this, SLOT(toggleMouseMode()),
+                                   actionCollection(), "legend_action");
+  _gfxLegendAction->setExclusiveGroup("gfx");
+  _gfxLegendAction->setToolTip(i18n("Insert Legend"));
+  _gfxLegendAction->setWhatsThis(i18n("Insert Legend"));
+
   _gfxLineAction = new KRadioAction(i18n("&Line"), "kst_gfx_line",
                                    KShortcut(Key_F10),
                                    this, SLOT(toggleMouseMode()),
@@ -853,6 +862,7 @@ void KstApp::initActions() {
   _gfxArrowAction->plug(mouseModeMenu);
   _gfxPictureAction->plug(mouseModeMenu);
   _gfx2DPlotAction->plug(mouseModeMenu);
+  _gfxLegendAction->plug(mouseModeMenu);
 
   toolBar()->insertButton("thumbnail", MODE_BUTTON_ID, mouseModeMenu, true, i18n("Select the desired mode"));
   toggleMouseMode();
@@ -969,31 +979,33 @@ void KstApp::delayedDocInit() {
 void KstApp::selectDataPlugin() {
   QStringList l;
 
-  // the new KstDataObject plugins...
-  QStringList newPlugins;
+  // the KstDataObject plugins...
+  QStringList dataObjectPlugins;
   const KstPluginInfoList pluginInfo = KstDataObject::pluginInfoList();
   {
     KstPluginInfoList::ConstIterator it = pluginInfo.begin();
     for (; it != pluginInfo.end(); ++it) {
-      newPlugins << it.key();
+      dataObjectPlugins << it.key();
     }
   }
 
-  l += newPlugins;
+  l += dataObjectPlugins;
 
-  // the old C style plugins...
-  QStringList oldPlugins;
+  // the C-style plugins...
+  QStringList cPlugins;
   const QMap<QString,QString> readable = PluginCollection::self()->readableNameList();
   {
     QMap<QString,QString>::const_iterator it = readable.begin();
     for (; it != readable.end(); ++it) {
-      oldPlugins << it.key();
+      cPlugins << it.key();
     }
   }
 
-  l += oldPlugins;
+  l += cPlugins;
 
-  // list the old and new stlye plugins together in ascending alphabetical order...
+  //
+  // list the KstDataObject and C-style plugins together in ascending alphabetical order...
+  //
   l.sort();
 
   bool ok = false;
@@ -1002,10 +1014,10 @@ void KstApp::selectDataPlugin() {
   if (ok && !plugin.isEmpty()) {
     const QString p = plugin.join("");
 
-    if (newPlugins.contains(p)) {
+    if (dataObjectPlugins.contains(p)) {
       KstDataObjectPtr ptr = KstDataObject::plugin(p);
       ptr->showDialog(true);
-    } else if (oldPlugins.contains(p)) {
+    } else if (cPlugins.contains(p)) {
       KstPluginDialogI::globalInstance()->showNew(readable[p]);
     }
   }
@@ -1066,6 +1078,7 @@ bool KstApp::openDocumentFile(const QString& in_filename,
   }
 
   opening = true;
+
   KURL url;
   bool rc = false;
 
@@ -1081,14 +1094,24 @@ bool KstApp::openDocumentFile(const QString& in_filename,
     setCaption(doc->title());
     if (url.isLocalFile()) {
       QFileInfo finfo(in_filename);
-      addRecentFile(finfo.absFilePath());
+      QString fileExport;
+
+      fileExport = finfo.absFilePath();
+      addRecentFile(fileExport);
+      if (fileExport.endsWith(QString(".kst"), FALSE)) {
+        fileExport.truncate(fileExport.length() - QString(".kst").length());
+      }
+      graphFileDlg()->setURL(fileExport);
     } else {
       addRecentFile(url);
     }
+
     rc = true;
   }
+
   slotUpdateStatusMsg(i18n("Ready"));
   opening = false;
+
   return rc;
 }
 
@@ -1850,6 +1873,10 @@ void KstApp::toggleMouseMode() {
     action = _gfxArrowAction;
     mode = KstTopLevelView::CreateMode;
     createType = "Arrow";
+  } else if (_gfxLegendAction->isChecked()) {
+    action = _gfxLegendAction;
+    mode = KstTopLevelView::CreateMode;
+    createType = "Legend";
   } else if (LayoutAction->isChecked()) {
     action = LayoutAction;
     mode = KstTopLevelView::LayoutMode;
@@ -2057,7 +2084,6 @@ void KstApp::updateDataNotifier() {
 
 
 void KstApp::updateDataDialogs(bool dm, bool vm) {
-
   ViewScalarsDialogAction->setEnabled(viewScalarsDialog->hasContent());
   ViewStringsDialogAction->setEnabled(viewStringsDialog->hasContent());
   ViewVectorsDialogAction->setEnabled(viewVectorsDialog->hasContent());
@@ -2533,8 +2559,29 @@ void KstApp::fromEnd() {
 void KstApp::updateMemoryStatus() {
 #ifdef HAVE_LINUX
   meminfo();
+
+  QString memoryAvailable;
   unsigned long mi = S(kb_main_free + kb_main_buffers + kb_main_cached);
-  slotUpdateMemoryMsg(i18n("%1 MB available").arg(mi / (1024 * 1024)));
+
+  mi /= 1024;
+  if (mi < 1024) {
+    memoryAvailable = i18n("abbreviation for kilobytes", "%1 kB").arg(mi);
+  } else {
+    mi /= 1024;
+    if (mi < 1024) {
+      memoryAvailable = i18n("abbreviation for megabytes", "%1 MB").arg(mi);
+    } else {
+      mi /= 1024;
+      if (mi < 1024) {
+        memoryAvailable = i18n("abbreviation for gigabytes", "%1 GB").arg(mi);
+      } else {
+        mi /= 1024;
+        memoryAvailable = i18n("abbreviation for terabytes", "%1 TB").arg(mi);
+      }
+    }
+  }
+
+  slotUpdateMemoryMsg(i18n("%1 available").arg(memoryAvailable));
 #endif
 }
 
