@@ -99,21 +99,21 @@ void KstBasicDialogI::init() {
   QStringList iv = ptr->inputVectorList();
   QStringList::ConstIterator ivI = iv.begin();
   for (; ivI != iv.end(); ++ivI) {
-      createInputVector(*ivI, ++cnt);
+    createInputVector(*ivI, ++cnt);
   }
 
   //Now, the inputScalars...
   QStringList is = ptr->inputScalarList();
   QStringList::ConstIterator isI = is.begin();
   for (; isI != is.end(); ++isI) {
-      createInputScalar(*isI, ++cnt);
+    createInputScalar(*isI, ++cnt, ptr->defaultScalarValue(*isI));
   }
 
   //Finally, the inputStrings...
   QStringList istr = ptr->inputStringList();
   QStringList::ConstIterator istrI = istr.begin();
   for (; istrI != istr.end(); ++istrI) {
-      createInputString(*istrI, ++cnt);
+    createInputString(*istrI, ++cnt);
   }
 
   //create sep
@@ -149,13 +149,24 @@ void KstBasicDialogI::init() {
 }
 
 
-void KstBasicDialogI::createInputVector(const QString &name, int row) {
-  QLabel *label = new QLabel(name + ":", _w->_frame);
+QString KstBasicDialogI::editTitle() {
+  return i18n("Edit ") + _pluginName;
+}
 
-  VectorSelector *widget = new VectorSelector(_w->_frame,
-                                              name.latin1());
-  connect(widget, SIGNAL(newVectorCreated(const QString&)),
-          this, SIGNAL(modified()));
+
+QString KstBasicDialogI::newTitle() {
+  return i18n("New ") + _pluginName;
+}
+
+
+void KstBasicDialogI::createInputVector(const QString &name, int row) {
+  QString labelName = name + "LABEL";
+  QLabel *label = new QLabel(name + ":", _w->_frame, labelName.latin1());
+
+  VectorSelector *widget = new VectorSelector(_w->_frame, name.latin1());
+  connect(widget, SIGNAL(newVectorCreated(const QString&)), this, SIGNAL(modified()));
+  connect(widget->_vector, SIGNAL(highlighted(int)), this, SLOT(wasModifiedApply()));
+  connect(widget->_vector, SIGNAL(textChanged(const QString&)), this, SLOT(wasModifiedApply()));
 
   _grid->addWidget(label, row, 0);
   label->show();
@@ -164,14 +175,19 @@ void KstBasicDialogI::createInputVector(const QString &name, int row) {
 }
 
 
-void KstBasicDialogI::createInputScalar(const QString &name, int row) {
-  QLabel *label = new QLabel(name + ":", _w->_frame);
+void KstBasicDialogI::createInputScalar(const QString &name, int row, double value) {
+  QString labelName = name + "LABEL";
+  QLabel *label = new QLabel(name + ":", _w->_frame, labelName.latin1());
+
+  ScalarSelector *widget = new ScalarSelector(_w->_frame, name.latin1());
+  connect(widget, SIGNAL(newScalarCreated()), this, SIGNAL(modified()));
+  connect(widget->_scalar, SIGNAL(highlighted(int)), this, SLOT(wasModifiedApply()));
+  connect(widget->_scalar, SIGNAL(textChanged(const QString&)), this, SLOT(wasModifiedApply()));
 
-  ScalarSelector *widget = new ScalarSelector(_w->_frame,
-                                              name.latin1());
-  connect(widget, SIGNAL(newScalarCreated()),
-          this, SIGNAL(modified()));
   widget->allowDirectEntry(true);
+  if (widget->_scalar->lineEdit()) {
+    widget->_scalar->lineEdit()->setText(QString::number(value));
+  }
 
   _grid->addWidget(label, row, 0);
   label->show();
@@ -181,12 +197,13 @@ void KstBasicDialogI::createInputScalar(const QString &name, int row) {
 
 
 void KstBasicDialogI::createInputString(const QString &name, int row) {
-  QLabel *label = new QLabel(name + ":", _w->_frame);
+  QString labelName = name + "LABEL";
+  QLabel *label = new QLabel(name + ":", _w->_frame, labelName.latin1());
 
-  StringSelector *widget = new StringSelector(_w->_frame,
-                                              name.latin1());
-  connect(widget, SIGNAL(newStringCreated()),
-          this, SIGNAL(modified()));
+  StringSelector *widget = new StringSelector(_w->_frame, name.latin1());
+  connect(widget, SIGNAL(newStringCreated()), this, SIGNAL(modified()));
+  connect(widget->_string, SIGNAL(highlighted(int)), this, SLOT(wasModifiedApply()));
+  connect(widget->_string, SIGNAL(textChanged(const QString&)), this, SLOT(wasModifiedApply()));
 
   _grid->addWidget(label, row, 0);
   label->show();
@@ -215,9 +232,8 @@ bool KstBasicDialogI::newObject() {
   //return false if the specified objects can't be made, otherwise true
 
   //Need to create a new object rather than use the one in KstDataObject pluginList
-  KstBasicPluginPtr ptr = kst_cast<KstBasicPlugin>(
-      KstDataObject::createPlugin(_pluginName));
-  Q_ASSERT(ptr); //should never happen...
+  KstBasicPluginPtr ptr = kst_cast<KstBasicPlugin>(KstDataObject::createPlugin(_pluginName));
+  Q_ASSERT(ptr);
 
   KstWriteLocker pl(ptr);
 
@@ -234,13 +250,22 @@ bool KstBasicDialogI::newObject() {
   ptr->setTagName(KstObjectTag::fromString(tagName));
 
   // Save the vectors and scalars
-  if (!editSingleObject(ptr) || !ptr->isValid()) {
-    KMessageBox::sorry(this, i18n("There is an error in the values you entered."));
+  QString error;
+  if (!editSingleObject(ptr, error) || !ptr->isValid()) {
+    QString str;
+
+    str = i18n("There is an error in the values you entered.");
+    if (!error.isEmpty()) {
+      str += "\n";
+      str += error;
+    }
+    KMessageBox::sorry(this, str);
     return false;
   }
 
-  //set the outputs
-  //output vectors...
+  // set the outputs
+
+  // output vectors...
   QStringList ov = ptr->outputVectorList();
   QStringList::ConstIterator ovI = ov.begin();
   for (; ovI != ov.end(); ++ovI) {
@@ -249,7 +274,7 @@ bool KstBasicDialogI::newObject() {
     }
   }
 
-  //output scalars...
+  // output scalars...
   QStringList os = ptr->outputScalarList();
   QStringList::ConstIterator osI = os.begin();
   for (; osI != os.end(); ++osI) {
@@ -258,7 +283,7 @@ bool KstBasicDialogI::newObject() {
     }
   }
 
-  //ouput strings...
+  // ouput strings...
   QStringList ostr = ptr->outputStringList();
   QStringList::ConstIterator ostrI = ostr.begin();
   for (; ostrI != ostr.end(); ++ostrI) {
@@ -285,8 +310,7 @@ bool KstBasicDialogI::newObject() {
 
 bool KstBasicDialogI::editObject() {
   //called upon clicking 'ok' in 'edit' mode
-  //return false if the specified objects can't be editted, otherwise true
-
+  //return false if the specified objects can't be edited, otherwise true
   KstBasicPluginPtr ptr = kst_cast<KstBasicPlugin>(_dp);
   Q_ASSERT(ptr); //should never happen...
 
@@ -298,7 +322,7 @@ bool KstBasicDialogI::editObject() {
     return false;
   }
 
-  ptr->setTagName(newTag);
+  ptr->setTagName(_tagName->text());
 
   ptr->inputVectors().clear();
   ptr->inputScalars().clear();
@@ -307,8 +331,17 @@ bool KstBasicDialogI::editObject() {
   ptr->unlock();
 
   // Save the vectors and scalars
-  if (!editSingleObject(ptr) || !ptr->isValid()) {
-    KMessageBox::sorry(this, i18n("There is an error in the values you entered."));
+  QString error;
+  if (!editSingleObject(ptr, error) || !ptr->isValid()) {
+    QString str;
+
+    str = i18n("There is an error in the values you entered.\n");
+    if (!error.isEmpty()) {
+      str += "\n";
+      str += error;
+    }
+    KMessageBox::sorry(this, str);
+
     return false;
   }
 
@@ -320,7 +353,6 @@ bool KstBasicDialogI::editObject() {
   }
 
   ptr->setDirty();
-
   emit modified();
   return true;
 }
@@ -345,7 +377,7 @@ void KstBasicDialogI::showEdit(const QString &field) {
 }
 
 
-bool KstBasicDialogI::editSingleObject(KstBasicPluginPtr ptr) {
+bool KstBasicDialogI::editSingleObject(KstBasicPluginPtr ptr, QString &error) {
 
   KstReadLocker vl(&KST::vectorList.lock());
   KstWriteLocker scl(&KST::scalarList.lock());
@@ -353,7 +385,7 @@ bool KstBasicDialogI::editSingleObject(KstBasicPluginPtr ptr) {
 
   { // leave this scope here to destroy the iterators
 
-    //input vectors...
+    // input vectors...
     KstVectorList::Iterator v;
     QStringList iv = ptr->inputVectorList();
     QStringList::ConstIterator ivI = iv.begin();
@@ -362,11 +394,16 @@ bool KstBasicDialogI::editSingleObject(KstBasicPluginPtr ptr) {
         v = KST::vectorList.findTag(w->selectedVector());
         if (v != KST::vectorList.end()) {
           ptr->setInputVector(*ivI, *v);
+        } else {
+          if (!error.isEmpty()) {
+            error += "\n";
+          }
+          error += i18n("%1 '%2' is not a valid vector name.").arg(label(*ivI)->text().latin1()).arg(w->_vector->currentText());
         }
       }
     }
 
-    //input scalars...
+    // input scalars...
     KstScalarList::Iterator s;
     QStringList is = ptr->inputScalarList();
     QStringList::ConstIterator isI = is.begin();
@@ -376,20 +413,23 @@ bool KstBasicDialogI::editSingleObject(KstBasicPluginPtr ptr) {
         if (s != KST::scalarList.end()) {
           ptr->setInputScalar(*isI, *s);
         } else {
-          //Deal with direct entry
+          // deal with direct entry
           bool ok;
           double val = w->_scalar->currentText().toDouble(&ok);
           if (ok) {
             KstScalarPtr sp = new KstScalar(KstObjectTag::fromString(w->_scalar->currentText()), 0L, val, true, false, false);  // FIXME: should this be a global-context scalar?
             ptr->setInputScalar(*isI, sp);
           } else {
-            return false;
+            if (!error.isEmpty()) {
+              error += "\n";
+            }
+            error += i18n("%1 '%2' is not a valid scalar name or value.").arg(label(*isI)->text().latin1()).arg(w->_scalar->currentText());
           }
         }
       }
     }
 
-    //input strings...
+    // input strings...
     KstStringList::Iterator str;
     QStringList istr = ptr->inputStringList();
     QStringList::ConstIterator istrI = istr.begin();
@@ -398,6 +438,11 @@ bool KstBasicDialogI::editSingleObject(KstBasicPluginPtr ptr) {
         str = KST::stringList.findTag(w->selectedString());
         if (str != KST::stringList.end()) {
           ptr->setInputString(*istrI, *str);
+        } else {
+          if (!error.isEmpty()) {
+            error += "\n";
+          }
+          error += i18n("%1 '%2' is not a valid string name.").arg(label(*istrI)->text().latin1()).arg(w->_string->currentText());
         }
       }
     }
@@ -417,7 +462,11 @@ void KstBasicDialogI::updateForm() {
   QStringList iv = ptr->inputVectorList();
   for (QStringList::ConstIterator ivI = iv.begin(); ivI != iv.end(); ++ivI) {
     if (VectorSelector *w = vector(*ivI)) {
+      disconnect(w->_vector, SIGNAL(highlighted(int)), this, SLOT(wasModifiedApply()));
+      disconnect(w->_vector, SIGNAL(textChanged(const QString&)), this, SLOT(wasModifiedApply()));
       w->update();
+      connect(w->_vector, SIGNAL(highlighted(int)), this, SLOT(wasModifiedApply()));
+      connect(w->_vector, SIGNAL(textChanged(const QString&)), this, SLOT(wasModifiedApply()));
     }
   }
 
@@ -425,7 +474,11 @@ void KstBasicDialogI::updateForm() {
   QStringList is = ptr->inputScalarList();
   for (QStringList::ConstIterator isI = is.begin(); isI != is.end(); ++isI) {
     if (ScalarSelector *w = scalar(*isI)) {
+      disconnect(w->_scalar, SIGNAL(highlighted(int)), this, SLOT(wasModifiedApply()));
+      disconnect(w->_scalar, SIGNAL(textChanged(const QString&)), this, SLOT(wasModifiedApply()));
       w->update();
+      connect(w->_scalar, SIGNAL(highlighted(int)), this, SLOT(wasModifiedApply()));
+      connect(w->_scalar, SIGNAL(textChanged(const QString&)), this, SLOT(wasModifiedApply()));
     }
   }
 
@@ -433,7 +486,11 @@ void KstBasicDialogI::updateForm() {
   QStringList istr = ptr->inputStringList();
   for (QStringList::ConstIterator istrI = istr.begin(); istrI != istr.end(); ++istrI) {
     if (StringSelector *w = string(*istrI)) {
+      disconnect(w->_string, SIGNAL(highlighted(int)), this, SLOT(wasModifiedApply()));
+      disconnect(w->_string, SIGNAL(textChanged(const QString&)), this, SLOT(wasModifiedApply()));
       w->update();
+      connect(w->_string, SIGNAL(highlighted(int)), this, SLOT(wasModifiedApply()));
+      connect(w->_string, SIGNAL(textChanged(const QString&)), this, SLOT(wasModifiedApply()));
     }
   }
 }
@@ -451,7 +508,7 @@ void KstBasicDialogI::fillFieldsForEdit() {
 
   //Update the various widgets...
 
-  //input vectors...
+  // input vectors...
   QStringList iv = ptr->inputVectorList();
   QStringList::ConstIterator ivI = iv.begin();
   for (; ivI != iv.end(); ++ivI) {
@@ -462,7 +519,7 @@ void KstBasicDialogI::fillFieldsForEdit() {
     }
   }
 
-  //input scalars...
+  // input scalars...
   QStringList is = ptr->inputScalarList();
   QStringList::ConstIterator isI = is.begin();
   for (; isI != is.end(); ++isI) {
@@ -473,7 +530,7 @@ void KstBasicDialogI::fillFieldsForEdit() {
     }
   }
 
-  //input strings...
+  // input strings...
   QStringList istr = ptr->inputStringList();
   QStringList::ConstIterator istrI = istr.begin();
   for (; istrI != istr.end(); ++istrI) {
@@ -484,7 +541,7 @@ void KstBasicDialogI::fillFieldsForEdit() {
     }
   }
 
-  //output vectors...
+  // output vectors...
   QStringList ov = ptr->outputVectorList();
   QStringList::ConstIterator ovI = ov.begin();
   for (; ovI != ov.end(); ++ovI) {
@@ -496,7 +553,7 @@ void KstBasicDialogI::fillFieldsForEdit() {
     }
   }
 
-  //output scalars...
+  // output scalars...
   QStringList os = ptr->outputScalarList();
   QStringList::ConstIterator osI = os.begin();
   for (; osI != os.end(); ++osI) {
@@ -508,7 +565,7 @@ void KstBasicDialogI::fillFieldsForEdit() {
     }
   }
 
-  //ouput strings...
+  // ouput strings...
   QStringList ostr = ptr->outputStringList();
   QStringList::ConstIterator ostrI = ostr.begin();
   for (; ostrI != ostr.end(); ++ostrI) {
@@ -553,10 +610,14 @@ StringSelector *KstBasicDialogI::string(const QString &name) const {
 }
 
 
+QLabel *KstBasicDialogI::label(const QString &name) const {
+  QString labelName = name + "LABEL";
+  return ::qt_cast<QLabel*>(_w->_frame->child(labelName.latin1()));
+}
+
+
 QLineEdit *KstBasicDialogI::output(const QString &name) const {
   return ::qt_cast<QLineEdit*>(_w->_frame->child(name.latin1()));
 }
 
 #include "kstbasicdialog_i.moc"
-
-// vim: ts=2 sw=2 et
