@@ -70,6 +70,8 @@ static QMap<int,Kst2DPlotPtr> PlotMap;
 #define RTTI_OBJ_MATRIX          4205
 #define RTTI_OBJ_DATA_MATRIX     4206
 #define RTTI_OBJ_STATIC_MATRIX   4207
+#define RTTI_OBJ_A_VECTOR        4208
+#define RTTI_OBJ_A_MATRIX        4209
 
 KstObjectItem::KstObjectItem(QListView *parent, KstRVectorPtr x, KstDataManagerI *dm, int localUseCount)
 : QObject(), KListViewItem(parent), _rtti(RTTI_OBJ_DATA_VECTOR), _tag(x->tag()), _dm(dm) {
@@ -93,6 +95,17 @@ KstObjectItem::KstObjectItem(QListView *parent, KstSVectorPtr x, KstDataManagerI
 }
 
 
+KstObjectItem::KstObjectItem(QListView *parent, KstAVectorPtr x, KstDataManagerI *dm, int localUseCount)
+: QObject(), KListViewItem(parent), _rtti(RTTI_OBJ_A_VECTOR), _tag(x->tag()), _dm(dm) {
+  assert(x);
+  _inUse = false;
+  setText(0, x->tag().tag());
+  setText(1, i18n("Static Vector"));
+  x = 0L; // keep the counts in sync
+  update(true, localUseCount);
+}
+
+
 KstObjectItem::KstObjectItem(KListViewItem *parent, KstVectorPtr x, KstDataManagerI *dm, int localUseCount)
 : QObject(), KListViewItem(parent), _rtti(RTTI_OBJ_VECTOR), _tag(x->tag()), _dm(dm) {
   assert(x);
@@ -148,6 +161,17 @@ KstObjectItem::KstObjectItem(QListView *parent, KstSMatrixPtr x, KstDataManagerI
 }
 
 
+KstObjectItem::KstObjectItem(QListView *parent, KstAMatrixPtr x, KstDataManagerI *dm, int localUseCount) 
+: QObject(), KListViewItem(parent), _rtti(RTTI_OBJ_A_MATRIX), _tag(x->tag()), _dm(dm) {
+  assert(x);
+  _inUse = false;
+  setText(0, x->tag().tag());
+  setText(1, i18n("Static Matrix"));
+  x = 0L; // keep the counts in sync
+  update(true, localUseCount);
+}
+
+
 KstObjectItem::KstObjectItem(KListViewItem *parent, KstMatrixPtr x, KstDataManagerI *dm, int localUseCount) 
 : QObject(), KListViewItem(parent), _rtti(RTTI_OBJ_MATRIX), _tag(x->tag()), _dm(dm) {
   assert(x);
@@ -237,6 +261,38 @@ void KstObjectItem::update(bool recursive, int localUseCount) {
       // Hmmm what happens if this if() fails??  We become inconsistent?
       break;
     }
+    case RTTI_OBJ_A_VECTOR:
+    {
+      KST::vectorList.lock().readLock();
+      KstAVectorPtr x = kst_cast<KstAVector>(*KST::vectorList.findTag(_tag));
+      KST::vectorList.lock().unlock();
+      if (x) {
+        x->readLock();
+        // getUsage: subtract 1 for KstRVectorPtr x
+        bool inUse = (x->getUsage() - 1 - localUseCount) > 0;
+        if (inUse != _inUse) {
+          _inUse = inUse;
+          setPixmap(2, inUse ? _dm->yesPixmap() : QPixmap());
+        }
+        QString field;
+        if (inUse) {
+          field = QString::number(x->length());
+        } else {
+          field = "-";
+        }
+        if (text(3) != field) {
+          setText(3, field);
+        }
+        field = i18n("[%1..%2]").arg(x->min()).arg(x->max());
+        if (text(4) != field) {
+          setText(4, field);
+        }
+        _removable = false;
+        x->unlock();
+      }
+      // Hmmm what happens if this if() fails??  We become inconsistent?
+      break;
+    }
     case RTTI_OBJ_VECTOR:
     {
       KST::vectorList.lock().readLock();
@@ -290,7 +346,7 @@ void KstObjectItem::update(bool recursive, int localUseCount) {
         } else {
           if (text(3) != "-") {
             setText(3, "-");
-          }          
+          }
         }
         field = x->propertyString();
         if (text(4) != field) {
@@ -366,13 +422,14 @@ void KstObjectItem::update(bool recursive, int localUseCount) {
           _inUse = inUse;
           setPixmap(2, inUse ? _dm->yesPixmap() : QPixmap());
         }
-        QString field = QString::number(x->sampleCount());
-        if (text(3) != field) {
-          setText(3, field);
+        QString field;
+        if (inUse) {
+          field = QString::number(x->sampleCount());
+        } else {
+          field = "-";
         }
         field = i18n("%1: %2 (%3 by %4)").arg(x->filename()).arg(x->field())
-                .arg(x->xNumSteps())
-                .arg(x->yNumSteps()); 
+                .arg(x->xNumSteps()).arg(x->yNumSteps());
         if (text(4) != field) {
           setText(4, field);
         }
@@ -394,9 +451,11 @@ void KstObjectItem::update(bool recursive, int localUseCount) {
           _inUse = inUse;
           setPixmap(2, inUse ? _dm->yesPixmap() : QPixmap());
         }
-        QString field = QString::number(x->sampleCount());
-        if (text(3) != field) {
-          setText(3, field);
+        QString field;
+        if (inUse) {
+          field = QString::number(x->sampleCount());
+        } else {
+          field = "-";
         }
         field = i18n("%1 to %2").arg(x->gradZMin()).arg(x->gradZMax());
         if (text(4) != field) {
@@ -407,6 +466,37 @@ void KstObjectItem::update(bool recursive, int localUseCount) {
       }
       break;
     }
+    case RTTI_OBJ_A_MATRIX:
+    {
+      KST::matrixList.lock().readLock();
+      KstAMatrixPtr x = kst_cast<KstAMatrix>(*KST::matrixList.findTag(_tag));
+      KST::matrixList.lock().unlock();
+      if (x) {
+        x->readLock();
+          // getUsage: subtract 1 for KstRMatrixPtr x
+        bool inUse = (x->getUsage() - 1 - localUseCount) > 0;
+        if (inUse != _inUse) {
+          _inUse = inUse;
+          setPixmap(2, inUse ? _dm->yesPixmap() : QPixmap());
+        }
+        QString field;
+        if (inUse) {
+          field = QString::number(x->sampleCount());
+        } else {
+          field = "-";
+        }
+        if (text(3) != field) {
+          setText(3, field);
+        }
+        field = i18n("[%1..%2]").arg(x->minValue()).arg(x->maxValue());
+        if (text(4) != field) {
+          setText(4, field);
+        }
+        _removable = false;
+        x->unlock();
+      }
+      break;
+    }
     case RTTI_OBJ_MATRIX:
     {
       KST::matrixList.lock().readLock();
@@ -421,7 +511,12 @@ void KstObjectItem::update(bool recursive, int localUseCount) {
           _inUse = inUse;
           setPixmap(2, inUse ? _dm->yesPixmap() : QPixmap());
         }
-        QString field = QString::number(x->sampleCount());
+        QString field;
+        if (inUse) {
+          field = QString::number(x->sampleCount());
+        } else {
+          field = "-";
+        }
         if (text(3) != field) {
           setText(3, field);
         }
@@ -478,11 +573,13 @@ void KstObjectItem::makeCurve() {
   KstCurveDialogI::globalInstance()->setVector(_tag.tag());
 }
 
+
 void KstObjectItem::makeCSD() {
   KstCsdDialogI::globalInstance()->show();
   KstCsdDialogI::globalInstance()->setVector(_tag.tag());
 }
 
+
 void KstObjectItem::makePSD() {
   KstPsdDialogI::globalInstance()->show();
   KstPsdDialogI::globalInstance()->setVector(_tag.tag());
@@ -867,9 +964,10 @@ void KstDataManagerI::update() {
       }
     } else if (i->rtti() == RTTI_OBJ_DATA_MATRIX || 
                i->rtti() == RTTI_OBJ_MATRIX ||
-               i->rtti() == RTTI_OBJ_STATIC_MATRIX) {
+               i->rtti() == RTTI_OBJ_STATIC_MATRIX ||
+               i->rtti() == RTTI_OBJ_A_MATRIX) {
       if (KST::matrixList.findTag(oi->tag().tagString()) == KST::matrixList.end()) {
-        trash.push(i);  
+        trash.push(i);
       }
     } else {
       if (KST::vectorList.findTag(oi->tag().tagString()) == KST::vectorList.end()) {
@@ -943,9 +1041,28 @@ void KstDataManagerI::update() {
     }
   }
 
+  // update the a vectors
+  KstAVectorList avl = kstObjectSubList<KstVector,KstAVector>(KST::vectorList);
+  for (KstAVectorList::iterator it = avl.begin(); it != avl.end(); ++it) {
+    KstReadLocker vl(*it);
+    bool found = false;
+    for (QListViewItem *i = DataView->firstChild(); i; i = i->nextSibling()) {
+      KstObjectItem *oi = static_cast<KstObjectItem*>(i);
+      if (oi->rtti() == RTTI_OBJ_A_VECTOR && oi->tag().tagString() == (*it)->tag().tagString()) {
+        oi->update(true, 1);
+        found = true;
+        break;
+      }
+    }
+    if (!found) {
+      KstObjectItem *i = new KstObjectItem(DataView, *it, this, 1);
+      connect(i, SIGNAL(updated()), this, SLOT(doUpdates()));
+    }
+  }
+
   KST::vectorList.lock().unlock();
 
-  // update the data matrices 
+  // update the data matrices
   KstRMatrixList rml = kstObjectSubList<KstMatrix,KstRMatrix>(KST::matrixList);
   for (KstRMatrixList::iterator it = rml.begin(); it != rml.end(); ++it) {
     KstReadLocker ml(*it);
@@ -983,6 +1100,25 @@ void KstDataManagerI::update() {
     }
   }
 
+  // update the a matrices
+  KstAMatrixList aml = kstObjectSubList<KstMatrix,KstAMatrix>(KST::matrixList);
+  for (KstAMatrixList::iterator it = aml.begin(); it != aml.end(); ++it) {
+    KstReadLocker ml(*it);
+    bool found = false;
+    for (QListViewItem *i = DataView->firstChild(); i; i = i->nextSibling()) {
+      KstObjectItem *oi = static_cast<KstObjectItem*>(i);
+      if (oi->rtti() == RTTI_OBJ_A_MATRIX && oi->tag().tagString() == (*it)->tag().tagString()) {
+        oi->update(true, 1);
+        found = true;
+        break;
+      }
+    }
+    if (!found) {
+      KstObjectItem *i = new KstObjectItem(DataView, *it, this, 1);
+      connect(i, SIGNAL(updated()), this, SLOT(doUpdates()));
+    }
+  }
+
   KST::matrixList.lock().unlock();
 
   // is this really necessary?  I would think not...
@@ -1021,6 +1157,8 @@ void KstDataManagerI::edit_I() {
     case RTTI_OBJ_STATIC_VECTOR:
       emit editStaticVector(qi->text(0));
       break;
+    case RTTI_OBJ_A_VECTOR:
+      break;
     case RTTI_OBJ_OBJECT:
       static_cast<KstObjectItem*>(qi)->dataObject()->showDialog(false);
       break;
@@ -1030,6 +1168,8 @@ void KstDataManagerI::edit_I() {
     case RTTI_OBJ_STATIC_MATRIX:
       emit editStaticMatrix(qi->text(0));  
       break;
+    case RTTI_OBJ_A_MATRIX:
+      break;
   default:
       break;
   }
@@ -1056,6 +1196,11 @@ void KstDataManagerI::delete_I() {
       KST::vectorList.removeTag(koi->tag().tagString());
       KST::vectorList.lock().unlock();
       doUpdates();
+    } else if (qi->rtti() == RTTI_OBJ_A_VECTOR) {
+      KST::vectorList.lock().writeLock();
+      KST::vectorList.removeTag(koi->tag().tagString());
+      KST::vectorList.lock().unlock();
+      doUpdates();
     } else if (qi->rtti() == RTTI_OBJ_DATA_MATRIX) {
       KST::matrixList.lock().writeLock();
       KST::matrixList.removeTag(koi->tag().tagString());
@@ -1066,7 +1211,13 @@ void KstDataManagerI::delete_I() {
       KST::matrixList.removeTag(koi->tag().tagString());
       KST::matrixList.lock().unlock();  
       doUpdates();
+    } else if (qi->rtti() == RTTI_OBJ_A_MATRIX) {
+      KST::matrixList.lock().writeLock();
+      KST::matrixList.removeTag(koi->tag().tagString());
+      KST::matrixList.lock().unlock();  
+      doUpdates();
     }
+
     update();
   } else {
     // Don't prompt for base curves
@@ -1100,6 +1251,18 @@ void KstDataManagerI::delete_I() {
         } else {
           KMessageBox::sorry(this, i18n("Unknown error deleting static vector."));
         }
+      } else if (qi->rtti() == RTTI_OBJ_A_VECTOR) {
+        KstAVectorPtr x = kst_cast<KstAVector>(*KST::vectorList.findTag(koi->tag().tagString()));
+        if (x) {
+          x->deleteDependents();
+          x = 0L;
+          KST::vectorList.lock().writeLock();
+          KST::vectorList.removeTag(koi->tag().tagString());
+          KST::vectorList.lock().unlock();
+          doUpdates();
+        } else {
+          KMessageBox::sorry(this, i18n("Unknown error deleting static vector."));
+        }
       } else if (qi->rtti() == RTTI_OBJ_DATA_MATRIX) {
         KstRMatrixPtr x = kst_cast<KstRMatrix>(*KST::matrixList.findTag(koi->tag().tagString()));
         if (x) {
@@ -1123,7 +1286,19 @@ void KstDataManagerI::delete_I() {
           doUpdates();
         } else {
           KMessageBox::sorry(this, i18n("Unknown error deleting static matrix."));
-        }  
+        }
+      } else if (qi->rtti() == RTTI_OBJ_A_MATRIX) {
+        KstAMatrixPtr x = kst_cast<KstAMatrix>(*KST::matrixList.findTag(koi->tag().tagString()));
+        if (x) {
+          x->deleteDependents();
+          x = 0L;
+          KST::matrixList.lock().writeLock();
+          KST::matrixList.removeTag(koi->tag().tagString());
+          KST::matrixList.lock().unlock();
+          doUpdates();
+        } else {
+          KMessageBox::sorry(this, i18n("Unknown error deleting static matrix."));
+        }
       }
       KstApp::inst()->paintAll(KstPainter::P_PLOT);
       update();
@@ -1262,6 +1437,4 @@ void KstDataManagerI::selectionChanged() {
   }
 }
 
-
 #include "kstdatamanager_i.moc"
-// vim: ts=2 sw=2 et
