@@ -25,8 +25,10 @@ class QToolBar;
 class KListViewSearchLineWidget;
 
 #include "datamanager.h"
+#include "kstavector.h"
 #include "kstrvector.h"
 #include "kstsvector.h"
+#include "kstamatrix.h"
 #include "kstrmatrix.h"
 #include "kstsmatrix.h"
 
@@ -95,8 +97,10 @@ class KstObjectItem : public QObject, public KListViewItem {
   public:
     KstObjectItem(QListView *parent, KstRVectorPtr x, KstDataManagerI *dm, int localUseCount = 0);
     KstObjectItem(QListView *parent, KstSVectorPtr x, KstDataManagerI *dm, int localUseCount = 0);
+    KstObjectItem(QListView *parent, KstAVectorPtr x, KstDataManagerI *dm, int localUseCount = 0);
     KstObjectItem(KListViewItem *parent, KstVectorPtr x, KstDataManagerI *dm, int localUseCount = 0);
     KstObjectItem(QListView *parent, KstDataObjectPtr x, KstDataManagerI *dm, int localUseCount = 0);
+    KstObjectItem(QListView *parent, KstAMatrixPtr x, KstDataManagerI *dm, int localUseCount = 0);
     KstObjectItem(QListView *parent, KstRMatrixPtr x, KstDataManagerI *dm, int localUseCount = 0);
     KstObjectItem(QListView *parent, KstSMatrixPtr x, KstDataManagerI *dm, int localUseCount = 0);
     KstObjectItem(KListViewItem *parent, KstMatrixPtr x, KstDataManagerI *dm, int localUseCount = 0);
@@ -135,4 +139,3 @@ class KstObjectItem : public QObject, public KListViewItem {
 };
 
 #endif
-// vim: ts=2 sw=2 et
