@@ -40,6 +40,7 @@
 #include "defaultprimitivenames.h"
 #include "fftoptionswidget.h"
 #include "kst2dplot.h"
+#include "kstchoosecolordialog_i.h"
 #include "kstdatacollection.h"
 #include "kstdataobject.h"
 #include "kstdataobjectcollection.h"
@@ -701,8 +702,45 @@ bool KstDataWizard::checkAvailableMemory(KstDataSourcePtr &ds, int f0Value, int
   ds->unlock();
 
   if (memoryRequested > memoryAvailable) {
-    KMessageBox::sorry(this, i18n("You requested to read in %1 MB of data but it seems that you only have approximately %2 MB of usable memory available.  You cannot load this much data.").arg(memoryRequested/(1024*1024)).arg(memoryAvailable/(1024*1024)));
-    rc = false;
+    QString strMemoryRequested;
+    QString strMemoryAvailable;
+
+    memoryRequested /= 1024;
+    memoryAvailable /= 1024;
+    if (memoryRequested < 10 * 1024) {
+      strMemoryRequested = i18n("abbreviation for kilobytes", "%1 kB").arg(memoryRequested);
+      strMemoryAvailable = i18n("abbreviation for kilobytes", "%1 kB").arg(memoryAvailable);
+    } else {
+      memoryRequested /= 1024;
+      memoryAvailable /= 1024;
+      if (memoryRequested < 10 * 1024) {
+        strMemoryRequested = i18n("abbreviation for megabytes", "%1 MB").arg(memoryRequested);
+        strMemoryAvailable = i18n("abbreviation for megabytes", "%1 MB").arg(memoryAvailable);
+      } else {
+        memoryRequested /= 1024;
+        memoryAvailable /= 1024;
+        if (memoryRequested < 10 * 1024) {
+          strMemoryRequested = i18n("abbreviation for gigabytes", "%1 GB").arg(memoryRequested);
+          strMemoryAvailable = i18n("abbreviation for gigabytes", "%1 GB").arg(memoryAvailable);
+        } else {
+          memoryRequested /= 1024;
+          memoryAvailable /= 1024;
+          strMemoryRequested = i18n("abbreviation for terabytes", "%1 TB").arg(memoryRequested);
+          strMemoryAvailable = i18n("abbreviation for terabytes", "%1 TB").arg(memoryAvailable);
+        }
+      }
+    }
+
+    if (strMemoryRequested != strMemoryAvailable) {
+      KMessageBox::sorry(this, i18n("You requested to read in over %1 of data but it seems that you have approximately only %2 of usable memory available. You cannot load this much data.").arg(strMemoryRequested).arg(strMemoryAvailable));
+      rc = false;
+    } else {
+      if (KMessageBox::questionYesNo(this, i18n("You requested to read in approximately %1 of data but it seems that you have slightly less usable memory than this available. Would you like to try and load the data anyway?").arg(strMemoryRequested)) == KMessageBox::Yes) {
+        rc = true;
+      } else {
+        rc = false;
+      }
+    }
   }
 
   return rc;
@@ -737,7 +775,7 @@ void KstDataWizard::createLegendsAndLabels(KstViewObjectList &plots, bool xLabel
 }
 
 
-void KstDataWizard::cleanupWindowLayout(KstViewObjectList &plots, KstViewWindow *window)
+void KstDataWizard::cleanupWindowLayout(KstViewWindow *window)
 {
   if (window) {
     //
@@ -950,15 +988,15 @@ void KstDataWizard::finished()
     KstViewObjectList plots;
 
     if (_onePlot->isChecked()) {
-      Kst2DPlotPtr p = kst_cast<Kst2DPlot>(window->view()->findChild(window->createObject<Kst2DPlot>(KST::suggestPlotName(), false)));
+      Kst2DPlotPtr p = kst_cast<Kst2DPlot>(window->view()->findChild(window->createPlotObject(KST::suggestPlotName(), false)));
       plots.append(p.data());
       if (_radioButtonPlotDataPSD->isChecked()) {
         Kst2DPlotPtr p;
 
         if (windowPSD) {
-          p = kst_cast<Kst2DPlot>(windowPSD->view()->findChild(windowPSD->createObject<Kst2DPlot>(KST::suggestPlotName(), false)));
+          p = kst_cast<Kst2DPlot>(windowPSD->view()->findChild(windowPSD->createPlotObject(KST::suggestPlotName(), false)));
         } else {
-           p = kst_cast<Kst2DPlot>(window->view()->findChild(window->createObject<Kst2DPlot>(KST::suggestPlotName(), false)));
+           p = kst_cast<Kst2DPlot>(window->view()->findChild(window->createPlotObject(KST::suggestPlotName(), false)));
         }
         plots.append(p.data());
         p->setXAxisInterpretation(false, KstAxisInterpretation(), KstAxisDisplay());
@@ -968,15 +1006,15 @@ void KstDataWizard::finished()
       Kst2DPlotPtr p;
 
       for (uint i = 0; i < vectorList.count(); ++i) {
-        p = kst_cast<Kst2DPlot>(window->view()->findChild(window->createObject<Kst2DPlot>(KST::suggestPlotName(), false)));
+        p = kst_cast<Kst2DPlot>(window->view()->findChild(window->createPlotObject(KST::suggestPlotName(), false)));
         plots.append(p.data());
       }
       if (_radioButtonPlotDataPSD->isChecked()) {
         for (uint i = 0; i < vectorList.count(); ++i) {
           if (windowPSD) {
-            p = kst_cast<Kst2DPlot>(windowPSD->view()->findChild(windowPSD->createObject<Kst2DPlot>(KST::suggestPlotName(), false)));
+            p = kst_cast<Kst2DPlot>(windowPSD->view()->findChild(windowPSD->createPlotObject(KST::suggestPlotName(), false)));
           } else {
-            p = kst_cast<Kst2DPlot>(window->view()->findChild(window->createObject<Kst2DPlot>(KST::suggestPlotName(), false)));
+            p = kst_cast<Kst2DPlot>(window->view()->findChild(window->createPlotObject(KST::suggestPlotName(), false)));
           }
           plots.append(p.data());
           p->setXAxisInterpretation(false, KstAxisInterpretation(), KstAxisDisplay());
@@ -994,15 +1032,15 @@ void KstDataWizard::finished()
     } else { /* cycle */
       Kst2DPlotPtr p;
       for (int i = 0; i < _plotNumber->value(); ++i) {
-        p = kst_cast<Kst2DPlot>(window->view()->findChild(window->createObject<Kst2DPlot>(KST::suggestPlotName(), false)));
+        p = kst_cast<Kst2DPlot>(window->view()->findChild(window->createPlotObject(KST::suggestPlotName(), false)));
         plots.append(p.data());
       }
       if (_radioButtonPlotDataPSD->isChecked()) {
         for (int i = 0; i < _plotNumber->value(); ++i) {
           if (windowPSD) {
-            p = kst_cast<Kst2DPlot>(windowPSD->view()->findChild(windowPSD->createObject<Kst2DPlot>(KST::suggestPlotName(), false)));
+            p = kst_cast<Kst2DPlot>(windowPSD->view()->findChild(windowPSD->createPlotObject(KST::suggestPlotName(), false)));
           } else {
-            p = kst_cast<Kst2DPlot>(window->view()->findChild(window->createObject<Kst2DPlot>(KST::suggestPlotName(), false)));
+            p = kst_cast<Kst2DPlot>(window->view()->findChild(window->createPlotObject(KST::suggestPlotName(), false)));
           }
           plots.append(p.data());
           p->setXAxisInterpretation(false, KstAxisInterpretation(), KstAxisDisplay());
@@ -1041,11 +1079,14 @@ void KstDataWizard::finished()
       if (_radioButtonPlotData->isChecked() || _radioButtonPlotDataPSD->isChecked()) {
         name = KST::suggestCurveName((*it)->tag(), false);
         Kst2DPlotPtr plot = kst_cast<Kst2DPlot>(*pit);
-        if (plot) {
-          KstVCurveList vcurves = kstObjectSubList<KstBaseCurve,KstVCurve>(plot->Curves);
-          color = KstColorSequence::next(vcurves, plot->backgroundColor());
-        } else {
-          color = KstColorSequence::next();
+        color = KstApp::inst()->chooseColorDlg()->getColorForCurve(xVector, *it);
+        if (!color.isValid()) {
+          if (plot) {
+            KstVCurveList vcurves = kstObjectSubList<KstBaseCurve,KstVCurve>(plot->Curves);
+            color = KstColorSequence::next(vcurves, plot->backgroundColor());
+          } else {
+            color = KstColorSequence::next();
+          }
         }
         colors.append(color);
         KstVCurvePtr c = new KstVCurve(name, xVector, *it, 0L, 0L, 0L, 0L, color);
@@ -1130,13 +1171,17 @@ void KstDataWizard::finished()
                   _kstFFTOptions->Sigma->value(),
                   PSDType(_kstFFTOptions->Output->currentItem()));
           p->setInterpolateHoles(_kstFFTOptions->InterpolateHoles->isChecked());
-          if (_radioButtonPlotPSD->isChecked() || colors.count() <= (unsigned long)indexColor) {
-            KstVCurveList vcurves = kstObjectSubList<KstBaseCurve,KstVCurve>(plot->Curves);
-            c = new KstVCurve(KST::suggestCurveName(p->tag(), true), p->vX(), p->vY(), 0L, 0L, 0L, 0L, KstColorSequence::next(vcurves, plot->backgroundColor()));
-          } else {
-            c = new KstVCurve(KST::suggestCurveName(p->tag(), true), p->vX(), p->vY(), 0L, 0L, 0L, 0L, colors[indexColor]);
-            indexColor++;
+          color = KstApp::inst()->chooseColorDlg()->getColorForCurve(p->vX(), p->vY());
+          if (!color.isValid()) {
+            if (_radioButtonPlotPSD->isChecked() || colors.count() <= (unsigned long)indexColor) {
+              KstVCurveList vcurves = kstObjectSubList<KstBaseCurve,KstVCurve>(plot->Curves);
+              color = KstColorSequence::next(vcurves, plot->backgroundColor());
+            } else {
+              color = colors[indexColor];
+              indexColor++;
+            }
           }
+          c = new KstVCurve(KST::suggestCurveName(p->tag(), true), p->vX(), p->vY(), 0L, 0L, 0L, 0L, color);
           c->setLineWidth(KstSettings::globalSettings()->defaultLineWeight);
           if (_drawBoth->isChecked()) {
             c->setHasPoints(true);
@@ -1172,8 +1217,8 @@ void KstDataWizard::finished()
 
     createLegendsAndLabels(plots, _xAxisLabels->isChecked(), _yAxisLabels->isChecked(), _plotTitles->isChecked(), _legendsOn->isChecked(), _legendsAuto->isChecked(), fontSize);
 
-    cleanupWindowLayout(plots, window);
-    cleanupWindowLayout(plots, windowPSD);
+    cleanupWindowLayout(window);
+    cleanupWindowLayout(windowPSD);
 
     app->slotUpdateProgress(0, 0, QString::null);
     if (!wasPaused) {
