@@ -91,10 +91,6 @@ EventMonitorEntry::EventMonitorEntry(const QDomElement &e) {
   }
 
   commonConstructor(strTag);
-
-  // wait for the initial update, as we don't want to trigger elog entries
-  // until we are sure the document is open.
-  //QTimer::singleShot(500, this, SLOT(slotUpdate()));
 }
 
 
@@ -172,13 +168,6 @@ EventMonitorEntry::~EventMonitorEntry() {
 }
 
 
-void EventMonitorEntry::slotUpdate() {
-  // possible deadlock?  bad idea.  updates should only happen in update thread
-  KstWriteLocker wl(this);
-  update();
-}
-
-
 KstObject::UpdateType EventMonitorEntry::update(int updateCounter) {
   Q_ASSERT(myLockStatus() == KstRWLock::WRITELOCKED);
 
@@ -189,11 +178,17 @@ KstObject::UpdateType EventMonitorEntry::update(int updateCounter) {
     return lastUpdateResult();
   }
 
-  writeLockInputsAndOutputs();
-
+  //
+  // do not call reparse() after writeLockInputsAndOutputs() as the call to reparse() may create input and output objects. 
+  // As a result the calls to writeLockInputsAndOutputs() and unlockInputsAndOutputs() would attempt
+  //  to lock and unlock different lists of objects...
+  //
   if (!_pExpression) {
     reparse();
   }
+
+  writeLockInputsAndOutputs();
+
   if (_isValid) {
     KstVectorPtr xv = *_xVector;
     KstVectorPtr yv = *_yVector;
@@ -338,13 +333,13 @@ void EventMonitorEntry::logImmediately(bool sendEvent) {
 
 
 bool EventMonitorEntry::event(QEvent *e) {
-    if (e->type() == EventMonitorEventType) {
-      readLock();
-      doLog(static_cast<EventMonitorEvent*>(e)->logMessage);
-      unlock();
-      return true;
-    }
-    return false;
+  if (e->type() == EventMonitorEventType) {
+    readLock();
+    doLog(static_cast<EventMonitorEvent*>(e)->logMessage);
+    unlock();
+    return true;
+  }
+  return false;
 }
 
 
@@ -578,10 +573,21 @@ bool EventMonitorEntry::uses(KstObjectPtr p) const {
       }
     }
   }
+
   return KstDataObject::uses(p);
 }
 
 
-#include "ksteventmonitorentry.moc"
+void EventMonitorEntry::setTagName(const QString &in_tag) {
+  KstObjectTag newTag(in_tag, tag().context());
 
-// vim: ts=2 sw=2 et
+  if (newTag == tag()) {
+    return;
+  }
+
+  KstObject::setTagName(newTag);
+  (*_xVector)->setTagName(KstObjectTag("x", tag()));
+  (*_yVector)->setTagName(KstObjectTag("y", tag()));
+}
+
+#include "ksteventmonitorentry.moc"
