@@ -67,7 +67,7 @@ KstImageDialogI::KstImageDialogI(QWidget* parent,
   connect(_w->_colorAndContour, SIGNAL(clicked()), this, SLOT(updateGroups()));
   connect(_w->_useVariableWeight, SIGNAL(clicked()), this, SLOT(updateEnables()));
   connect(_w->_realTimeAutoThreshold, SIGNAL(clicked()), this, SLOT(updateEnables()));
-  
+
   // for multiple edit mode
   connect(_w->_colorOnly, SIGNAL(clicked()), this, SLOT(setColorOnlyDirty()));
   connect(_w->_contourOnly, SIGNAL(clicked()), this, SLOT(setContourOnlyDirty()));
@@ -75,6 +75,27 @@ KstImageDialogI::KstImageDialogI(QWidget* parent,
   connect(_w->_realTimeAutoThreshold, SIGNAL(clicked()), this, SLOT(setRealTimeAutoThresholdDirty()));
   connect(_w->_useVariableWeight, SIGNAL(clicked()), this, SLOT(setUseVariableWeightDirty()));
   connect(_w->_contourColor, SIGNAL(clicked()), this, SLOT(setContourColorDirty()));
+
+  // for apply button
+  connect(_w->_matrix, SIGNAL(selectionChanged(const QString&)), this, SLOT(wasModifiedApply()));
+  connect(_w->_matrix, SIGNAL(selectionChangedLabel(const QString&)), this, SLOT(wasModifiedApply()));
+  connect(_w->_colorOnly, SIGNAL(clicked()), this, SLOT(wasModifiedApply()));
+  connect(_w->_contourOnly, SIGNAL(clicked()), this, SLOT(wasModifiedApply()));
+  connect(_w->_colorAndContour, SIGNAL(clicked()), this, SLOT(wasModifiedApply()));
+  connect(_w->_colorPalette->_palette, SIGNAL(highlighted(int)), this, SLOT(wasModifiedApply()));
+  connect(_w->_lowerZ, SIGNAL(textChanged(const QString&)), this, SLOT(wasModifiedApply()));
+  connect(_w->_upperZ, SIGNAL(textChanged(const QString&)), this, SLOT(wasModifiedApply()));
+  connect(_w->_autoThreshold, SIGNAL(clicked()), this, SLOT(wasModifiedApply()));
+  connect(_w->_smartThreshold, SIGNAL(clicked()), this, SLOT(wasModifiedApply()));
+  connect(_w->_smartThresholdValue, SIGNAL(valueChanged(double)), this, SLOT(wasModifiedApply()));
+  connect(_w->_smartThresholdValue->child("qt_spinbox_edit"), SIGNAL(textChanged(const QString&)), this, SLOT(wasModifiedApply()));
+  connect(_w->_realTimeAutoThreshold, SIGNAL(clicked()), this, SLOT(wasModifiedApply()));
+  connect(_w->_numContourLines, SIGNAL(valueChanged(int)), this, SLOT(wasModifiedApply()));
+  connect(_w->_numContourLines->child("qt_spinbox_edit"), SIGNAL(textChanged(const QString&)), this, SLOT(wasModifiedApply()));
+  connect(_w->_contourColor, SIGNAL(changed(const QColor&)), this, SLOT(wasModifiedApply()));
+  connect(_w->_contourWeight, SIGNAL(valueChanged(int)), this, SLOT(wasModifiedApply()));
+  connect(_w->_contourWeight->child("qt_spinbox_edit"), SIGNAL(textChanged(const QString&)), this, SLOT(wasModifiedApply()));
+  connect(_w->_useVariableWeight, SIGNAL(clicked()), this, SLOT(wasModifiedApply()));
 }
 
 
@@ -92,10 +113,10 @@ void KstImageDialogI::fillFieldsForEdit() {
 
   KstImagePtr ip = kst_cast<KstImage>(_dp);
   if (!ip) {
-    return; // shouldn't be needed
+    return;
   }
   ip->readLock();
-  
+
   // set the type of image
   _w->_colorOnly->setChecked(ip->hasColorMap() && !ip->hasContourMap());
   _w->_contourOnly->setChecked(ip->hasContourMap() && !ip->hasColorMap());
@@ -398,7 +419,7 @@ bool KstImageDialogI::editSingleObject(KstImagePtr imPtr) {
 
 bool KstImageDialogI::editObject() {
   KstImageList imList = kstObjectSubList<KstDataObject,KstImage>(KST::dataObjectList);
-  
+
   // if editing multiple objects, edit each one
   if (_editMultipleMode) {
     _numContourLinesDirty = _w->_numContourLines->text() != " ";
@@ -499,6 +520,7 @@ void KstImageDialogI::calcSmartThreshold() {
   }
 }
 
+
 void KstImageDialogI::placeInPlot(KstImagePtr image) {
   KstViewWindow *w = dynamic_cast<KstViewWindow*>(KstApp::inst()->findWindow(_w->_curvePlacement->_plotWindow->currentText()));
   if (!w) {
