@@ -37,6 +37,7 @@
 #include <kmessagebox.h>
 
 // application specific includes
+#include "curveappearancewidget.h"
 #include "kst.h"
 #include "kstplugindialog_i.h"
 #include "kstdataobjectcollection.h"
@@ -64,8 +65,10 @@ KstPluginDialogI::KstPluginDialogI(QWidget* parent, const char* name, bool modal
 : KstDataDialog(parent, name, modal, fl) {
   _w = new PluginDialogWidget(_contents);
   setMultiple(false);
+  connect(_w->PluginCombo, SIGNAL(highlighted(int)), this, SLOT(wasModifiedApply()));
   connect(_w->PluginCombo, SIGNAL(activated(int)), this, SLOT(pluginChanged(int)));
   connect(_w->_pluginManager, SIGNAL(clicked()), this, SLOT(showPluginManager()));
+  connect(_w->_curveAppearance, SIGNAL(changed()), this, SLOT(wasModifiedApply()));
 
   _pluginInfoGrid = 0L;
   _pluginInputOutputGrid = 0L;
@@ -611,7 +614,7 @@ bool KstPluginDialogI::editObject() {
     return false;
   }
 
-  pp->setTagName(KstObjectTag(_tagName->text(), KstObjectTag::globalTagContext));  // FIXME: tag context always global?
+  pp->setTagName(_tagName->text());
 
   int pitem = _w->PluginCombo->currentItem();
   KstSharedPtr<Plugin> pPtr = PluginCollection::self()->plugin(_pluginList[pitem]);
@@ -715,6 +718,8 @@ void KstPluginDialogI::generateEntries(bool input, int& cnt, QWidget *parent, QG
       if (scalar) {
         ScalarSelector *w = new ScalarSelector(parent, (*it)._name.latin1());
         widget = w;
+        connect(w->_scalar, SIGNAL(highlighted(int)), this, SLOT(wasModifiedApply()));
+        connect(w->_scalar, SIGNAL(textChanged(const QString&)), this, SLOT(wasModifiedApply()));
         connect(w->_scalar, SIGNAL(activated(const QString&)), this, SLOT(updateScalarTooltip(const QString&)));
         connect(widget, SIGNAL(newScalarCreated()), this, SIGNAL(modified()));
         if (!(*it)._default.isEmpty()) {
@@ -732,6 +737,8 @@ void KstPluginDialogI::generateEntries(bool input, int& cnt, QWidget *parent, QG
       } else if (string) {
         StringSelector *w = new StringSelector(parent, (*it)._name.latin1());
         widget = w;
+        connect(w->_string, SIGNAL(highlighted(int)), this, SLOT(wasModifiedApply()));
+        connect(w->_string, SIGNAL(textChanged(const QString&)), this, SLOT(wasModifiedApply()));
         connect(w->_string, SIGNAL(activated(const QString&)), this, SLOT(updateStringTooltip(const QString&)));
         connect(widget, SIGNAL(newStringCreated()), this, SIGNAL(modified()));
         if (!(*it)._default.isEmpty()) {
@@ -747,7 +754,16 @@ void KstPluginDialogI::generateEntries(bool input, int& cnt, QWidget *parent, QG
           p->unlock();
         }
       } else {
-        widget = new VectorSelector(parent, (*it)._name.latin1());
+        VectorSelector *vectorSelector = new VectorSelector(parent, (*it)._name.latin1());
+        widget = dynamic_cast<QWidget*>(vectorSelector);
+        if ((*it)._optional) {
+          KstVectorPtr vector;
+
+          vectorSelector->provideNoneVector(true);
+          vectorSelector->setSelection(vector);
+        }
+        connect(vectorSelector->_vector, SIGNAL(highlighted(int)), this, SLOT(wasModifiedApply()));
+        connect(vectorSelector->_vector, SIGNAL(textChanged(const QString&)), this, SLOT(wasModifiedApply()));
         connect(widget, SIGNAL(newVectorCreated(const QString&)), this, SIGNAL(modified()));
       }
     } else {
@@ -886,7 +902,4 @@ void KstPluginDialogI::updateStringTooltip(const QString& n) {
   }
 }
 
-
 #include "kstplugindialog_i.moc"
-
-// vim: ts=2 sw=2 et
