@@ -82,6 +82,27 @@ KstVectorDialogI::KstVectorDialogI(QWidget* parent, const char* name,
   connect(_w->_kstDataRange->DoFilter, SIGNAL(clicked()), this, SLOT(setDoFilterDirty()));
   connect(_w->_kstDataRange->DoSkip, SIGNAL(clicked()), this, SLOT(setDoSkipDirty()));
 
+  // for apply button
+  connect(_w->_readFromSource, SIGNAL(clicked()), this, SLOT(wasModifiedApply()));
+  connect(_w->_generateX, SIGNAL(clicked()), this, SLOT(wasModifiedApply()));
+  connect(_w->_configure, SIGNAL(clicked()), this, SLOT(wasModifiedApply()));
+  connect(_w->FileName, SIGNAL(textChanged(const QString&)), this, SLOT(wasModifiedApply()));
+  connect(_w->Field, SIGNAL(highlighted(int)), this, SLOT(wasModifiedApply()));
+  connect(_w->Field, SIGNAL(completion(const QString&)), this, SLOT(wasModifiedApply()));
+  connect(_w->_N, SIGNAL(valueChanged(int)), this, SLOT(wasModifiedApply()));
+  connect(_w->_N->child("qt_spinbox_edit"), SIGNAL(textChanged(const QString&)), this, SLOT(wasModifiedApply()));
+  connect(_w->_xMin, SIGNAL(textChanged(const QString&)), this, SLOT(wasModifiedApply()));
+  connect(_w->_xMax, SIGNAL(textChanged(const QString&)), this, SLOT(wasModifiedApply()));
+  connect(_w->_kstDataRange->F0, SIGNAL(textChanged(const QString&)), this, SLOT(wasModifiedApply()));
+  connect(_w->_kstDataRange->_startUnits, SIGNAL(highlighted(int)), this, SLOT(wasModifiedApply()));
+  connect(_w->_kstDataRange->N, SIGNAL(textChanged(const QString&)), this, SLOT(wasModifiedApply()));
+  connect(_w->_kstDataRange->_rangeUnits, SIGNAL(highlighted(int)), this, SLOT(wasModifiedApply()));
+  connect(_w->_kstDataRange->CountFromEnd, SIGNAL(clicked()), this, SLOT(wasModifiedApply()));
+  connect(_w->_kstDataRange->ReadToEnd, SIGNAL(clicked()), this, SLOT(wasModifiedApply()));
+  connect(_w->_kstDataRange->DoSkip, SIGNAL(clicked()), this, SLOT(wasModifiedApply()));
+  connect(_w->_kstDataRange->Skip, SIGNAL(valueChanged(int)), this, SLOT(wasModifiedApply()));
+  connect(_w->_kstDataRange->DoFilter, SIGNAL(clicked()), this, SLOT(wasModifiedApply()));
+
   _w->_configure->setEnabled(false);
   _fieldCompletion = _w->Field->completionObject();
   _w->Field->setAutoDeleteCompletionObject(true);
@@ -151,7 +172,7 @@ void KstVectorDialogI::updateCompletion() {
   QString current_text = _w->Field->currentText();
   _w->Field->clear();
 
-  /* update filename list and ll axes combo boxes */
+  // update filename list and ll axes combo boxes
   KST::dataSourceList.lock().readLock();
   KstDataSourcePtr ds = *KST::dataSourceList.findReusableFileName(_w->FileName->url());
   KST::dataSourceList.lock().unlock();
@@ -225,11 +246,11 @@ void KstVectorDialogI::fillFieldsForRVEdit() {
 
   _tagName->setText(rvp->tagName());
 
-  /* fill the fields */
   _w->Field->clear();
   if (_fieldCompletion) {
     _fieldCompletion->clear();
   }
+
   {
     KstDataSourcePtr tf;
     KST::dataSourceList.lock().readLock();
@@ -251,22 +272,23 @@ void KstVectorDialogI::fillFieldsForRVEdit() {
     }
     KST::dataSourceList.lock().unlock();
   }
+
   _w->Field->setEnabled(_w->Field->count() > 0);
   _ok->setEnabled(_w->Field->isEnabled());
   _w->Field->setCurrentText(rvp->field());
 
-  /* select the proper file */
+  // select the proper file
   _w->FileName->setURL(rvp->filename());
 
-  /* fill the vector range entries */
+  // fill the vector range entries
   _w->_kstDataRange->CountFromEnd->setChecked(rvp->countFromEOF());
   _w->_kstDataRange->setF0Value(rvp->reqStartFrame());
 
-  /* fill number of frames entries */
+  // fill number of frames entries
   _w->_kstDataRange->ReadToEnd->setChecked(rvp->readToEOF());
   _w->_kstDataRange->setNValue(rvp->reqNumFrames());
 
-  /* fill in frames to skip box */
+  // fill in frames to skip box
   _w->_kstDataRange->Skip->setValue(rvp->skip());
   _w->_kstDataRange->DoSkip->setChecked(rvp->doSkip());
   _w->_kstDataRange->DoFilter->setChecked(rvp->doAve());
@@ -327,7 +349,7 @@ void KstVectorDialogI::fillFieldsForNew() {
 
   _tagName->setText(defaultTag);
 
-  /* set defaults with vectorDefaults */
+  // set defaults with vectorDefaults
   KST::vectorDefaults.sync();
   _w->FileName->setURL(KST::vectorDefaults.dataSource());
   updateCompletion();
@@ -347,7 +369,7 @@ bool KstVectorDialogI::newObject() {
     tag_name.replace(defaultTag, _w->Field->currentText());
     tag_name = KST::suggestVectorName(tag_name);
 
-    /* if there is not an active DataSource, create one */
+    // if there is not an active DataSource, create one
     {
       KST::dataSourceList.lock().writeLock();
       KstDataSourceList::Iterator it = KST::dataSourceList.findReusableFileName(_w->FileName->url());
@@ -407,7 +429,7 @@ bool KstVectorDialogI::newObject() {
     }
     file->unlock();
 
-    /* create the vector */
+    // create the vector
     KstRVectorPtr vector = new KstRVector(
         file, _w->Field->currentText(),
         KstObjectTag(tag_name, file->tag(), false),
@@ -463,16 +485,17 @@ bool KstVectorDialogI::editSingleObjectSV(KstVectorPtr vcPtr) {
   svp->writeLock();
   svp->changeRange(p_xMin, p_xMax, p_N);
   svp->unlock();
+
   return true;
 }
 
 
 bool KstVectorDialogI::editSingleObjectRV(KstVectorPtr vcPtr) {
   KstRVectorPtr rvp = kst_cast<KstRVector>(vcPtr);
-
   KstDataSourcePtr file;
+
   if (_fileNameDirty) {
-    /* if there is not an active KstFile, create one */
+    // if there is not an active KstFile, create one
     KST::dataSourceList.lock().writeLock();
     KstDataSourceList::Iterator it = KST::dataSourceList.findReusableFileName(_w->FileName->url());
 
@@ -510,6 +533,7 @@ bool KstVectorDialogI::editSingleObjectRV(KstVectorPtr vcPtr) {
       }
     }
   }
+
   file->writeLock();
   if (rvp) {
     QString pField;
@@ -525,6 +549,7 @@ bool KstVectorDialogI::editSingleObjectRV(KstVectorPtr vcPtr) {
     }
 
     int f0 = 0, n = 0;
+
     if (_f0Dirty) {
       if (_w->_kstDataRange->isStartRelativeTime()) {
         f0 = file->sampleForTime(_w->_kstDataRange->f0Value());
@@ -555,6 +580,7 @@ bool KstVectorDialogI::editSingleObjectRV(KstVectorPtr vcPtr) {
         n = int(_w->_kstDataRange->nValue());
       }
     }
+
     // use existing requested start and number of frames if not dirty
     rvp->readLock();
     if (!_f0Dirty) {
@@ -563,9 +589,11 @@ bool KstVectorDialogI::editSingleObjectRV(KstVectorPtr vcPtr) {
     if (!_nDirty) {
       n = rvp->reqNumFrames();
     }
+
     // other parameters for multiple edit
     bool pCountFromEnd, pReadToEnd, pDoSkip, pDoFilter;
     int pSkip;
+
     if (_countFromEndDirty) {
       pCountFromEnd = _w->_kstDataRange->CountFromEnd->isChecked();
     } else {
@@ -598,11 +626,9 @@ bool KstVectorDialogI::editSingleObjectRV(KstVectorPtr vcPtr) {
 
     rvp->unlock();
 
-    /* change the vector */
+    // change the vector
     rvp->writeLock();
-
     rvp->change(file, pField, rvp->tag(), pCountFromEnd ?  -1 : f0, pReadToEnd ?  -1 : n, pSkip, pDoSkip, pDoFilter);
-
     rvp->unlock();
   } else {
     KstSVectorPtr svp = kst_cast<KstSVector>(_dp);
@@ -610,16 +636,18 @@ bool KstVectorDialogI::editSingleObjectRV(KstVectorPtr vcPtr) {
       file->unlock();
       return true; // shouldn't be needed
     }
+
     double x0 = _w->_xMin->text().toDouble();
     double x1 = _w->_xMax->text().toDouble();
     int n = _w->_N->value();
-//    QString tagname = _tagName->text();
+
     svp->writeLock();
     svp->changeRange(x0, x1, n);
     svp->setTagName(KstObjectTag(_tagName->text(), svp->tag().context())); // FIXME: doesn't verify uniqueness, doesn't allow changing tag context
     svp->unlock();
   }
   file->unlock();
+
   return true;
 }
 
@@ -852,6 +880,4 @@ KstObjectPtr KstVectorDialogI::findObject(const QString& name) {
   return o;
 }
 
-
 #include "kstvectordialog_i.moc"
-// vim: sw=2 ts=2 et
