@@ -67,25 +67,38 @@ void KstViewMatricesDialogI::updateViewMatricesDialog() {
 
 
 void KstViewMatricesDialogI::updateViewMatricesDialog(const QString& matrixName) {
-  int needed = 0;
-  
   KST::matrixList.lock().readLock();
   KstMatrixPtr matrix = *KST::matrixList.findTag(matrixName);
   KST::matrixList.lock().unlock();
   if (matrix) {
+    bool updated = false;
+    int xneeded = 0;
+    int yneeded = 0;
+
     matrix->readLock();
-    
-    needed = matrix->xNumSteps();
-    if (needed != _tableMatrices->numCols()) {
-      _tableMatrices->setNumCols(needed);
-    }    
-    
-    needed = matrix->yNumSteps();
-    if (needed != _tableMatrices->numRows()) {
-      _tableMatrices->setNumRows(needed);
-    }  
-        
+    xneeded = matrix->xNumSteps();
+    yneeded = matrix->yNumSteps();
     matrix->unlock();
+
+    if (xneeded != _tableMatrices->numCols()) {
+      _tableMatrices->setNumCols(xneeded);
+      updated = true;
+    }
+
+    if (yneeded != _tableMatrices->numRows()) {
+      _tableMatrices->setNumRows(yneeded);
+      updated = true;
+    }
+
+    if (!updated) {
+      //
+      // following two lines appear to be necessary to ensure a full update...
+      //
+      _tableMatrices->hide();
+      _tableMatrices->show();
+
+      _tableMatrices->update();
+    }
   }
 }
 
@@ -101,6 +114,13 @@ void KstViewMatricesDialogI::showViewMatricesDialog() {
 void KstViewMatricesDialogI::matrixChanged(const QString& matrix) {
   updateViewMatricesDialog(matrix);
   _tableMatrices->setMatrix(matrix);
+
+  //
+  // following two lines appear to be necessary to ensure a full update...
+  //
+  _tableMatrices->hide();
+  _tableMatrices->show();
+
   _tableMatrices->update();
 }
 
@@ -120,4 +140,3 @@ void KstViewMatricesDialogI::updateDefaults(int index) {
 }
 
 #include "kstviewmatricesdialog_i.moc"
-// vim: ts=2 sw=2 et
