@@ -299,7 +299,11 @@ void KstViewObject::saveAttributes(QTextStream& ts, const QString& indent) {
   // save all properties
   for (int i = 0; i < metaObject()->numProperties(true); i++) {
     ts << indent << "<" << metaObject()->property(i, true)->name() << ">";
-    ts << property(metaObject()->property(i, true)->name()).toString().latin1();
+    if (strcmp(metaObject()->property(i, true)->type(), "QString") == 0) {
+      ts << QStyleSheet::escape(property(metaObject()->property(i, true)->name()).toString());
+    } else {
+      ts << property(metaObject()->property(i, true)->name()).toString().latin1();
+    }
     ts << "</" << metaObject()->property(i, true)->name() << ">" << endl;
   }
 }
@@ -412,9 +416,6 @@ void KstViewObject::paintSelf(KstPainter& p, const QRegion& bounds) {
   if (!bounds.isNull()) {
     p.setClipRegion(bounds);
   }
-  if (!transparent()) {
-    p.fillRect(geometry(), _backgroundColor);
-  }
 }
 
 
@@ -635,7 +636,7 @@ QSize KstViewObject::size() const {
 
 
 void KstViewObject::internalAlignment(KstPainter& p, QRect& plotRegion) {
-  static const QRect x(0,0,0,0);
+  static const QRect x(0, 0, 0, 0);
 
   for (KstViewObjectList::Iterator i = _children.begin(); i != _children.end(); ++i) {
     (*i)->internalAlignment(p, plotRegion);
@@ -643,7 +644,7 @@ void KstViewObject::internalAlignment(KstPainter& p, QRect& plotRegion) {
       KST::alignment.setPosition((*i)->geometry(), plotRegion);
     }
   }
-  
+
   plotRegion = x;
 }
 
@@ -723,12 +724,16 @@ void KstViewObject::cleanup(int cols) {
   //
   // if cols <= 0, the optimal value is chosen automatically
   //
-
   KstViewObjectList childrenCopy;
   double widthTotal = 0.0;
   double widthAverage = 0.0;
 
-  for (KstViewObjectList::ConstIterator i = _children.begin(); i != _children.end(); ++i) {
+  for (KstViewObjectList::Iterator i = _children.begin(); i != _children.end(); ++i) {
+    if ((*i)->maximized()) {
+      (*i)->setMaximized(false);
+      (*i)->recursively<bool>(&KstViewObject::setMaximized, false);
+    }
+
     if ((*i)->followsFlow()) {
       childrenCopy.append(*i);
       widthTotal += (*i)->aspectRatio().w;
@@ -966,6 +971,17 @@ void KstViewObject::move(const QPoint& pos) {
 }
 
 
+void KstViewObject::modifyGeometry(const QRect& rect) {
+  QRect geomOld = _geom;
+
+  _geom = rect;
+  updateAspectPos();
+  for (KstViewObjectList::Iterator i = _children.begin(); i != _children.end(); ++i) {
+    (*i)->updateAspect();
+  }
+}
+
+
 void KstViewObject::setFocus(bool focus) {
   _focus = focus;
 }
@@ -1463,6 +1479,35 @@ void KstViewObject::lower() {
 }
 
 
+void KstViewObject::remove() {
+  KstApp::inst()->document()->setModified();
+  KstViewObjectPtr vop(this);
+  KstViewObjectPtr tlp = topLevelParent();
+
+  if (tlp) {
+    KstTopLevelViewPtr tlv = kst_cast<KstTopLevelView>(tlp);
+
+    if (tlv && vop == tlv->pressTarget()) {
+      tlv->clearPressTarget();
+    }
+
+    if (this->_parent) {
+      this->_parent->invalidateClipRegion();
+    }
+
+    tlp->removeChild(this, true);
+    tlp = 0L;
+  }
+
+  while (!_children.isEmpty()) {
+    removeChild(_children.first());
+  }
+
+  vop = 0L; // basically "delete this;"
+  QTimer::singleShot(0, KstApp::inst(), SLOT(updateDialogs()));
+}
+
+
 void KstViewObject::moveTo(int id) {
   QString windowName = _moveToMap[id];
 
@@ -1494,7 +1539,7 @@ void KstViewObject::copyTo(int id) {
       setDirty();
       KstApp::inst()->document()->setModified();
       copyObjectQuietly(*(window->view().data()));
-      window->view()->paint(KstPainter::P_PAINT);    
+      window->view()->paint(KstPainter::P_PAINT);
     }
   }
 }
@@ -1503,24 +1548,31 @@ void KstViewObject::copyTo(int id) {
 void KstViewObject::updateFromAspect() {
   // FIXME: also take into account the maximum minimum child size in our children
   setMinimumSize(minimumSize().expandedTo(QSize(_children.count(), _children.count())));
+
   const QRect myOldGeom(_geom);
+
   if (_parent) {
-    const QRect geom(_parent->contentsRect());
-    _geom.setLeft(geom.left() + int(_aspect.x * geom.width()));
-    _geom.setTop(geom.top() + int(_aspect.y * geom.height()));
-    _geom.setRight(geom.left() + int((_aspect.x + _aspect.w) * geom.width()) - 1);
-    _geom.setBottom(geom.top() + int((_aspect.y + _aspect.h) * geom.height()) - 1);
+    const QRect geom(_parent->geometry());
+
+    _geom.setLeft(geom.left() + int((_aspect.x * (double)geom.width())+0.5));
+    _geom.setTop(geom.top() + int((_aspect.y * (double)geom.height())+0.5));
+    _geom.setRight(geom.left() + int(((_aspect.x + _aspect.w) * (double)geom.width()) - 0.5));
+    _geom.setBottom(geom.top() + int(((_aspect.y + _aspect.h) * (double)geom.height()) - 0.5));
 
     if (_maintainAspect == true) {
       QSize maintaining_size(_idealSize);
-      maintaining_size.scale(_geom.size(),QSize::ScaleMin);
+
+      maintaining_size.scale(_geom.size(), QSize::ScaleMin);
       _geom.setSize(maintaining_size);
     }
   }
+
   if (_geom.width() < _minimumSize.width() || _geom.height() < _minimumSize.height()) {
     _geom.setSize(_geom.size().expandedTo(_minimumSize));
   }
+
   assert(_geom.left() >= 0 && _geom.top() >= 0 && !_geom.size().isNull());
+
   if (myOldGeom != _geom) {
     setDirty();
   }
@@ -1529,7 +1581,8 @@ void KstViewObject::updateFromAspect() {
 
 void KstViewObject::updateAspectPos() {
   if (_parent) {
-    const QRect geom(_parent->contentsRect());
+    const QRect geom(_parent->geometry());
+
     _aspect.x = double(geometry().left() - geom.left()) / double(geom.width());
     _aspect.y = double(geometry().top() - geom.top()) / double(geom.height());
   } else {
@@ -1541,7 +1594,8 @@ void KstViewObject::updateAspectPos() {
 
 void KstViewObject::updateAspectSize() {
   if (_parent) {
-    const QRect geom(_parent->contentsRect());
+    const QRect geom(_parent->geometry());
+
     _aspect.w = double(geometry().width()) / double(geom.width());
     _aspect.h = double(geometry().height()) / double(geom.height());
   } else {
@@ -1928,6 +1982,11 @@ bool KstViewObject::transparent() const {
 }
 
 
+bool KstViewObject::complexObject() const {
+  return false;
+}
+
+
 QRegion KstViewObject::clipRegion() {
   if (_clipMask.isNull()) {
     if (transparent()) {
@@ -2141,7 +2200,7 @@ bool KstViewObject::isResizable() const {
 void KstViewObject::invalidateClipRegion() {
   _clipMask = QRegion();
   if (_parent) {
-    if (_parent->transparent()) {
+    if (_parent->complexObject() || _parent->transparent()) {
       _parent->invalidateClipRegion();
     }
   }
