@@ -29,6 +29,7 @@
 #include "kstbasicplugin.h"
 #include "dialoglauncher.h"
 #include "kstdatacollection.h"
+#include "kstdataobjectcollection.h"
 
 KstBasicPlugin::KstBasicPlugin()
 : KstDataObject(), _isFit(false) {
@@ -83,6 +84,7 @@ KstDataObjectPtr KstBasicPlugin::makeDuplicate(KstDataObjectDataObjectMap &map)
   return KstDataObjectPtr(plugin);
 }
 
+
 void KstBasicPlugin::showNewDialog() {
   //FIXME shouldn't tagName() == propertyString() ??
   KstDialogs::self()->showBasicPluginDialog(propertyString());
@@ -96,55 +98,61 @@ void KstBasicPlugin::showEditDialog() {
 
 KstVectorPtr KstBasicPlugin::inputVector(const QString& vector) const {
   KstVectorMap::ConstIterator i = _inputVectors.find(vector);
-  if (i != _inputVectors.end())
+  if (i != _inputVectors.end()) {
     return *i;
-  else
+  } else {
     return 0;
+  }
 }
 
 
 KstScalarPtr KstBasicPlugin::inputScalar(const QString& scalar) const {
   KstScalarMap::ConstIterator i = _inputScalars.find(scalar);
-  if (i != _inputScalars.end())
+  if (i != _inputScalars.end()) {
     return *i;
-  else
+  } else {
     return 0;
+  }
 }
 
 
 KstStringPtr KstBasicPlugin::inputString(const QString& string) const {
   KstStringMap::ConstIterator i = _inputStrings.find(string);
-  if (i != _inputStrings.end())
+  if (i != _inputStrings.end()) {
     return *i;
-  else
+  } else {
     return 0;
+  }
 }
 
 
 KstVectorPtr KstBasicPlugin::outputVector(const QString& vector) const {
   KstVectorMap::ConstIterator i = _outputVectors.find(vector);
-  if (i != _outputVectors.end())
+  if (i != _outputVectors.end()) {
     return *i;
-  else
+  } else {
     return 0;
+  }
 }
 
 
 KstScalarPtr KstBasicPlugin::outputScalar(const QString& scalar) const {
   KstScalarMap::ConstIterator i = _outputScalars.find(scalar);
-  if (i != _outputScalars.end())
+  if (i != _outputScalars.end()) {
     return *i;
-  else
+  } else {
     return 0;
+  }
 }
 
 
 KstStringPtr KstBasicPlugin::outputString(const QString& string) const {
   KstStringMap::ConstIterator i = _outputStrings.find(string);
-  if (i != _outputStrings.end())
+  if (i != _outputStrings.end()) {
     return *i;
-  else
+  } else {
     return 0;
+  }
 }
 
 
@@ -217,8 +225,9 @@ KstObject::UpdateType KstBasicPlugin::update(int updateCounter) {
   }
 
   //Make sure we have all the necessary inputs
-  if (!inputsExist())
+  if (!inputsExist()) {
     return setLastUpdateResult(NO_CHANGE);
+  }
 
   writeLockInputsAndOutputs();
 
@@ -250,7 +259,7 @@ void KstBasicPlugin::load(const QDomElement &e) {
     QDomElement e = n.toElement();
     if (!e.isNull()) {
       if (e.tagName() == "tag") {
-        setTagName(KstObjectTag::fromString(e.text()));
+        KstObject::setTagName(KstObjectTag::fromString(e.text()));
       } else if (e.tagName() == "ivector") {
         _inputVectorLoadQueue.append(qMakePair(e.attribute("name"), e.text()));
       } else if (e.tagName() == "iscalar") {
@@ -281,7 +290,65 @@ void KstBasicPlugin::load(const QDomElement &e) {
 }
 
 
-// FIXME: KstBasicPlugin should not know about fit scalars!!
+//
+// to be used only from javaScript...
+//
+bool KstBasicPlugin::isValid() const {
+  return inputsExist();
+}
+
+
+//
+// to be used only from javaScript...
+//
+bool KstBasicPlugin::validate() {
+  bool rc = false;
+
+  if (isValid()) {
+    _outputVectors.clear();
+    _outputScalars.clear();
+    _outputStrings.clear();
+
+    //
+    // output vectors...
+    //
+    QStringList ov = outputVectorList();
+    for (QStringList::ConstIterator ovI = ov.begin(); ovI != ov.end(); ++ovI) {
+      setOutputVector(*ovI, "");
+    }
+
+    //
+    // output scalars...
+    //
+    QStringList os = outputScalarList();
+    for (QStringList::ConstIterator osI = os.begin(); osI != os.end(); ++osI) {
+      setOutputScalar(*osI, "");
+    }
+
+    //
+    // ouput strings...
+    //
+    QStringList ostr = outputStringList();
+    for (QStringList::ConstIterator ostrI = ostr.begin(); ostrI != ostr.end(); ++ostrI) {
+      setOutputString(*ostrI, "");
+    }
+
+    KstDataObjectList::Iterator oi = KST::dataObjectList.findTag(tagName());
+    if (oi == KST::dataObjectList.end()) {
+      KST::dataObjectList.lock().writeLock();
+      KST::dataObjectList.append(this);
+      KST::dataObjectList.lock().unlock();
+    }
+
+    setDirty(true);
+
+    rc = true;
+  }
+
+  return rc;
+}
+
+
 void KstBasicPlugin::createFitScalars() {
   // Assumes that this is called with a write lock in place on this object
   Q_ASSERT(myLockStatus() == KstRWLock::WRITELOCKED);
@@ -313,8 +380,10 @@ void KstBasicPlugin::createFitScalars() {
 }
 
 
-QString KstBasicPlugin::parameterName(int /*index*/) const {
-    return QString::null;
+QString KstBasicPlugin::parameterName(int index) const {
+  Q_UNUSED(index)
+
+  return QString::null;
 }
 
 
@@ -345,6 +414,7 @@ QString KstBasicPlugin::label(int precision) const {
 
 void KstBasicPlugin::save(QTextStream& ts, const QString& indent) {
   QString l2 = indent + "  ";
+
   //The plugin name _must_ be the same as the entry in the .desktop file
   ts << indent << "<plugin name=\"" << propertyString() << "\">" << endl;
   ts << l2 << "<tag>" << QStyleSheet::escape(tagName()) << "</tag>" << endl;
@@ -391,25 +461,29 @@ bool KstBasicPlugin::inputsExist() const {
   QStringList iv = inputVectorList();
   QStringList::ConstIterator ivI = iv.begin();
   for (; ivI != iv.end(); ++ivI) {
-    if (!inputVector(*ivI))
+    if (!inputVector(*ivI)) {
       return false;
+    }
   }
 
   //Now, check the inputScalars...
   QStringList is = inputScalarList();
   QStringList::ConstIterator isI = is.begin();
   for (; isI != is.end(); ++isI) {
-    if (!inputScalar(*isI))
+    if (!inputScalar(*isI)) {
       return false;
+    }
   }
 
   //Finally, check the inputStrings...
   QStringList istr = inputStringList();
   QStringList::ConstIterator istrI = istr.begin();
   for (; istrI != istr.end(); ++istrI) {
-    if (!inputString(*istrI))
+    if (!inputString(*istrI)) {
       return false;
+    }
   }
+
   return true;
 }
 
@@ -422,8 +496,7 @@ bool KstBasicPlugin::updateInput(int updateCounter, bool force) const {
   QStringList::ConstIterator ivI = iv.begin();
   for (; ivI != iv.end(); ++ivI) {
     Q_ASSERT(inputVector(*ivI)->myLockStatus() == KstRWLock::WRITELOCKED);
-    depUpdated =
-        UPDATE == inputVector(*ivI)->update(updateCounter) || depUpdated;
+    depUpdated = UPDATE == inputVector(*ivI)->update(updateCounter) || depUpdated;
   }
 
   //Now, update the inputScalars...
@@ -431,8 +504,7 @@ bool KstBasicPlugin::updateInput(int updateCounter, bool force) const {
   QStringList::ConstIterator isI = is.begin();
   for (; isI != is.end(); ++isI) {
     Q_ASSERT(inputScalar(*isI)->myLockStatus() == KstRWLock::WRITELOCKED);
-    depUpdated =
-        UPDATE == inputScalar(*isI)->update(updateCounter) || depUpdated;
+    depUpdated = UPDATE == inputScalar(*isI)->update(updateCounter) || depUpdated;
   }
 
   //Finally, update the inputStrings...
@@ -440,9 +512,9 @@ bool KstBasicPlugin::updateInput(int updateCounter, bool force) const {
   QStringList::ConstIterator istrI = istr.begin();
   for (; istrI != istr.end(); ++istrI) {
     Q_ASSERT(inputString(*istrI)->myLockStatus() == KstRWLock::WRITELOCKED);
-    depUpdated =
-        UPDATE == inputString(*istrI)->update(updateCounter) || depUpdated;
+    depUpdated = UPDATE == inputString(*istrI)->update(updateCounter) || depUpdated;
   }
+
   return depUpdated;
 }
 
@@ -482,4 +554,41 @@ void KstBasicPlugin::updateOutput(int updateCounter) const {
   }
 }
 
-// vim: ts=2 sw=2 et
+double KstBasicPlugin::defaultScalarValue(const QString& name) const {
+  double value = 0.0;
+
+  QMap<QString, double>::ConstIterator it;
+
+  it = _inputScalarDefaults.find(name);
+  if (it != _inputScalarDefaults.end()) {
+    value = *it;
+  }
+
+  return value;
+}
+
+
+void KstBasicPlugin::setTagName(const KstObjectTag& tag) {
+  KstObject::setTagName(tag);
+}
+
+
+void KstBasicPlugin::setTagName(const QString &in_tag) {
+  KstObjectTag newTag(in_tag, tag().context());
+
+  if (newTag == tag()) {
+    return;
+  }
+
+  KstObject::setTagName(newTag);
+
+  for (KstVectorMap::Iterator iter = outputVectors().begin(); iter != outputVectors().end(); ++iter) {
+    (*iter)->setTagName(KstObjectTag(iter.data()->tag().tag(), tag()));
+  }
+  for (KstScalarMap::Iterator iter = outputScalars().begin(); iter != outputScalars().end(); ++iter) {
+    (*iter)->setTagName(KstObjectTag(iter.data()->tag().tag(), tag()));
+  }
+  for (KstStringMap::Iterator iter = outputStrings().begin(); iter != outputStrings().end(); ++iter) {
+    (*iter)->setTagName(KstObjectTag(iter.data()->tag().tag(), tag()));
+  }
+}
