@@ -50,6 +50,9 @@ class KST_EXPORT KstBasicPlugin : public KstDataObject {
     //Provide an impl...
     virtual KstDataObjectPtr makeDuplicate(KstDataObjectDataObjectMap&);
 
+    virtual void setTagName(const QString& tag);
+    virtual void setTagName(const KstObjectTag& tag);
+
   public slots:
     //Pure virtual slots from KstDataObject
     //Each plugin can provide an implementation or use the default
@@ -67,6 +70,8 @@ class KST_EXPORT KstBasicPlugin : public KstDataObject {
     KstScalarPtr outputScalar(const QString& name) const;
     KstStringPtr outputString(const QString& name) const;
 
+    double defaultScalarValue(const QString& name) const;
+
     void setInputVector(const QString &type, KstVectorPtr ptr);
     void setInputScalar(const QString &type, KstScalarPtr ptr);
     void setInputString(const QString &type, KstStringPtr ptr);
@@ -83,12 +88,16 @@ class KST_EXPORT KstBasicPlugin : public KstDataObject {
     void save(QTextStream& ts, const QString& indent = QString::null);
 
     bool isFit() const { return _isFit; }
-    // FIXME: remove this
     void createFitScalars();
     QString label(int precision) const;
 
+    virtual bool isValid() const;
+    virtual bool validate();
+
   protected:
     virtual QString parameterName(int index) const;
+
+    QMap<QString, double> _inputScalarDefaults;
     bool _isFit;
 
   private:
@@ -101,5 +110,3 @@ typedef KstSharedPtr<KstBasicPlugin> KstBasicPluginPtr;
 typedef KstObjectList<KstBasicPluginPtr> KstBasicPluginList;
 
 #endif
-
-// vim: ts=2 sw=2 et
