@@ -33,7 +33,8 @@ enum KstAxisInterpretation {
   AXIS_INTERP_JD,
   AXIS_INTERP_MJD,
   AXIS_INTERP_RJD,
-  AXIS_INTERP_AIT };
+  AXIS_INTERP_AIT,
+  AXIS_INTERP_AIT_NANO };
 
 enum KstAxisDisplay { 
   AXIS_DISPLAY_YEAR,
@@ -74,7 +75,8 @@ const AxisInterpretation AxisInterpretations[] = {
   { I18N_NOOP2("Julian Date", "JD"), AXIS_INTERP_JD },
   { I18N_NOOP2("Modified Julian Date", "MJD"), AXIS_INTERP_MJD },
   { I18N_NOOP2("Reduced Julian Date", "RJD"), AXIS_INTERP_RJD },
-  { I18N_NOOP2("Temps Atomique International", "TAI"), AXIS_INTERP_AIT }
+  { I18N_NOOP2("Temps Atomique International", "TAI"), AXIS_INTERP_AIT },
+  { I18N_NOOP2("Temps Atomique International - Nanoseconds", "TAI (ns)"), AXIS_INTERP_AIT_NANO }
 };
 
 const AxisDisplay AxisDisplays[] = {
@@ -123,4 +125,3 @@ const unsigned int numAxisDisplays = sizeof( AxisDisplays ) / sizeof( AxisDispla
 const unsigned int numMajorTickSpacings = sizeof( MajorTickSpacings ) / sizeof( MajorTickSpacing );
 
 #endif
-// vim: ts=2 sw=2 et
