@@ -61,6 +61,7 @@ KstVectorView::KstVectorView(const QString &in_tag, KstVectorPtr in_X, KstVector
   commonConstructor(in_tag);
 }
 
+
 KstVectorView::KstVectorView(const QDomElement &e)
 : KstDataObject(e) {
 
@@ -129,12 +130,22 @@ KstVectorView::KstVectorView(const QDomElement &e)
 
 
 void KstVectorView::commonConstructor(const QString &in_tag) {
+  KstVectorPtr v;
+  QString tagName;
+
   _typeString = i18n("Vector View");
   _type = "VectorView";
 
-  setTagName(KstObjectTag::fromString(in_tag));
+  if (in_tag.isEmpty()) {
+    if (_inputVectors[IN_XVECTOR]) {
+      tagName = KST::suggestVectorViewName(_inputVectors[IN_XVECTOR]->tag());
+    }
+  } else {
+    tagName = in_tag;
+  }
+  KstObject::setTagName(KstObjectTag::fromString(tagName));
 
-  KstVectorPtr v = new KstVector(KstObjectTag("X", tag()), 0, this);
+  v = new KstVector(KstObjectTag("X", tag()), 0, this);
   _cxVector = _outputVectors.insert(OUT_XVECTOR, v);
 
   v = new KstVector(KstObjectTag("Y", tag()), 0, this);
@@ -227,10 +238,9 @@ KstObject::UpdateType KstVectorView::update(int update_counter) {
       break;
   }
 
-  int NSm1 = NS-1;
-
   double *outXArr;
   double *outYArr;
+  int NSm1 = NS-1;
 
   if (inXVec->length() == NS && inXVec->isRising()) { //good scenario.
     int i_bot = inXVec->indexNearX(xmin, NS); //closest index to xmin
@@ -257,8 +267,9 @@ KstObject::UpdateType KstVectorView::update(int update_counter) {
 
     int in = 0;
     double yv;
+
     for (long i=i_bot; i<=i_top; i++) {
-        if (!flagVec || !flagVec->interpolate(i, NS)) { //only the LHS should be evaluated !flagVec
+        if (!flagVec || !flagVec->interpolate(i, NS)) {
           yv = inYVec->interpolate(i, NS);
           if (ymin <= yv && ymax >= yv) {
             outXArr[in] = inXArr[i];
@@ -302,10 +313,11 @@ KstObject::UpdateType KstVectorView::update(int update_counter) {
 
     int in = 0;
     double xv;
+
     for (long i=i_bot; i<=i_top; i++) {
-        if (!flagVec || !flagVec->interpolate(i, NS)) { //only the LHS should be evaluated !flagVec
+        if (!flagVec || !flagVec->interpolate(i, NS)) {
           xv = inXVec->interpolate(i, NS);
-          if ( (xmin <= xv) && (xmax >= xv) ) {
+          if (xmin <= xv && xmax >= xv) {
             outXArr[in] = inYArr[i];
             outYArr[in] = xv;
             in++;
@@ -335,8 +347,9 @@ KstObject::UpdateType KstVectorView::update(int update_counter) {
 
     int in = 0;
     double yv;
+
     for (long i=0; i<=NSm1; i++) {
-      if (!flagVec || !flagVec->interpolate(i, NS)) { //only the LHS should be evaluated if !flagVec.
+      if (!flagVec || !flagVec->interpolate(i, NS)) {
         double xv = inXVec->interpolate(i, NS);
         if (xmin <= xv && xmax >= xv) {
           yv = inYVec->interpolate(i,NS);
@@ -365,6 +378,7 @@ KstObject::UpdateType KstVectorView::update(int update_counter) {
   return setLastUpdateResult(UPDATE);
 }
 
+
 void KstVectorView::setXminScalar(KstScalarPtr xmin) {
   if (xmin != _xmin) {
     if (_xmin != 0L) {
@@ -377,6 +391,7 @@ void KstVectorView::setXminScalar(KstScalarPtr xmin) {
   }
 }
 
+
 void KstVectorView::setXmaxScalar(KstScalarPtr xmax) {
   if (xmax != _xmax) {
     if (_xmax != 0L) {
@@ -389,6 +404,7 @@ void KstVectorView::setXmaxScalar(KstScalarPtr xmax) {
   }
 }
 
+
 void KstVectorView::setYminScalar(KstScalarPtr ymin) {
   if (ymin != _ymin) {
     if (_ymin != 0L) {
@@ -401,6 +417,7 @@ void KstVectorView::setYminScalar(KstScalarPtr ymin) {
   }
 }
 
+
 void KstVectorView::setYmaxScalar(KstScalarPtr ymax) {
   if (ymax != _ymax) {
     if (_ymax != 0L) {
@@ -413,6 +430,7 @@ void KstVectorView::setYmaxScalar(KstScalarPtr ymax) {
   }
 }
 
+
 void KstVectorView::setUseXmin(bool useXmin) {
   _useXmin = useXmin;
 
@@ -426,6 +444,7 @@ void KstVectorView::setUseXmin(bool useXmin) {
   }
 }
 
+
 void KstVectorView::setUseXmax(bool useXmax) {
   _useXmax = useXmax;
 
@@ -439,6 +458,7 @@ void KstVectorView::setUseXmax(bool useXmax) {
   }
 }
 
+
 void KstVectorView::setUseYmin(bool useYmin) {
   _useYmin = useYmin;
 
@@ -452,6 +472,7 @@ void KstVectorView::setUseYmin(bool useYmin) {
   }
 }
 
+
 void KstVectorView::setUseYmax(bool useYmax) {
   _useYmax = useYmax;
 
@@ -465,14 +486,17 @@ void KstVectorView::setUseYmax(bool useYmax) {
   }
 }
 
+
 void KstVectorView::setXVector(KstVectorPtr new_v) {
   _inputVectors[IN_XVECTOR] = new_v;
 }
 
+
 void KstVectorView::setYVector(KstVectorPtr new_v) {
   _inputVectors[IN_YVECTOR] = new_v;
 }
 
+
 void KstVectorView::setFlagVector(KstVectorPtr Flag) {
   if (Flag) {
     _inputVectors[IN_FLAGVECTOR] = Flag;
@@ -482,33 +506,38 @@ void KstVectorView::setFlagVector(KstVectorPtr Flag) {
   setDirty();
 }
 
+
 bool KstVectorView::hasFlag() {
   return _inputVectors.contains(IN_FLAGVECTOR);
 }
 
+
 QString KstVectorView::xLabel() const {
   return _inputVectors[IN_XVECTOR]->label();
 }
 
+
 QString KstVectorView::yLabel() const {
   return _inputVectors[IN_YVECTOR]->label();
 }
 
+
 QString KstVectorView::in_xVTag() const {
   return _inputVectors[IN_XVECTOR]->tag().displayString();
 }
 
+
 QString KstVectorView::in_yVTag() const {
   return _inputVectors[IN_YVECTOR]->tag().displayString();
 }
 
+
 QString KstVectorView::FlagTag() const {
   return _inputVectors[IN_FLAGVECTOR]->tag().displayString();
 }
 
+
 void KstVectorView::save(QTextStream &ts, const QString& indent) {
-  // FIXME: clean this up - all lower case nodes, maybe save points in the
-  // point class itself, etc
   QString l2 = indent + "  ";
   ts << indent << "<vectorview>" << endl;
   ts << l2 << "<tag>" << QStyleSheet::escape(tagName()) << "</tag>" << endl;
@@ -544,10 +573,12 @@ void KstVectorView::showEditDialog() {
   KstDialogs::self()->showVectorViewDialog(tagName(), true);
 }
 
+
 bool KstVectorView::slaveVectorsUsed() const {
   return true;
 }
 
+
 KstDataObjectPtr KstVectorView::makeDuplicate(KstDataObjectDataObjectMap& duplicatedMap) {
   QString name(tagName() + '\'');
   while (KstData::self()->dataTagNameNotUnique(name, false)) {
@@ -558,17 +589,33 @@ KstDataObjectPtr KstVectorView::makeDuplicate(KstDataObjectDataObjectMap& duplic
   return KstDataObjectPtr(vectorview);
 }
 
+
 void KstVectorView::scalarChanged() {
     setDirty();
 }
 
+
 KstVectorView::InterpType KstVectorView::interp() const {
   return (_interp);
 }
 
+
 void KstVectorView::setInterp(KstVectorView::InterpType itype) {
   _interp = itype;
   setDirty();
 }
 
+
+void KstVectorView::setTagName(const QString &in_tag) {
+  KstObjectTag newTag(in_tag, tag().context());
+
+  if (newTag == tag()) {
+    return;
+  }
+
+  KstObject::setTagName(newTag);
+  (*_cxVector)->setTagName(KstObjectTag("X", tag()));
+  (*_cyVector)->setTagName(KstObjectTag("Y", tag()));
+}
+
 #include "kstvectorview.moc"
